@@ -195,6 +195,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
 
   finishRestore ();
 
+  fileOpenRecent->loadEntries( KConfigGroup(sconfig, "Recent Files" ) );
+
   setAcceptDrops(true);
 
   connect(KateSessionManager::self(), SIGNAL(sessionChanged()), this, SLOT(updateCaption()));
@@ -263,7 +265,7 @@ void KateMainWindow::setupMainWindow ()
 #if 0
   KateMDI::ToolView *t = createToolView("kate_fileselector", KMultiTabBar::Left, SmallIcon("document-open"), i18n("Filesystem Browser"));
   fileselector = new KateFileSelector( this, m_viewManager, t, "operator");
-  connect(fileselector->dirOperator(), SIGNAL(fileSelected(const KFileItem*)), this, SLOT(fileSelected(const KFileItem*)));
+  connect(fileselector->dirOperator(), SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
 #endif
 
   // make per default the filelist visible, if we are in session restore, katemdi will skip this ;)
@@ -297,7 +299,7 @@ void KateMainWindow::setupActions()
   a->setText( i18n( "Close Other" ) );
   connect( a, SIGNAL( triggered() ), this, SLOT( slotDocumentCloseOther() ) );
   a->setWhatsThis(i18n("Close other open documents."));
-  
+
   a = actionCollection()->addAction( "file_close_all" );
   a->setText( i18n( "Clos&e All" ) );
   connect( a, SIGNAL( triggered() ), this, SLOT( slotDocumentCloseAll() ) );
@@ -496,8 +498,6 @@ void KateMainWindow::readOptions ()
   m_paShowPath->setChecked (generalGroup.readEntry("Show Full Path in Title", false));
   m_paShowStatusBar->setChecked (generalGroup.readEntry("Show Status Bar", true));
 
-  fileOpenRecent->loadEntries(KConfigGroup(config, "Recent Files"));
-
   // emit signal to hide/show statusbars
   toggleShowStatusBar ();
 }
@@ -515,7 +515,6 @@ void KateMainWindow::saveOptions ()
   generalGroup.writeEntry("Show Full Path in Title", m_paShowPath->isChecked());
   generalGroup.writeEntry("Show Status Bar", m_paShowStatusBar->isChecked());
 
-  fileOpenRecent->saveEntries(KConfigGroup(config, "Recent Files"));
 #ifdef __GNUC__
 #warning PORTME
 #endif
@@ -697,13 +696,13 @@ KUrl KateMainWindow::activeDocumentUrl()
 }
 
 #if 0
-void KateMainWindow::fileSelected(const KFileItem * /*file*/)
+void KateMainWindow::fileSelected(const KFileItem & /*file*/)
 {
-  const KFileItemList *list = fileselector->dirOperator()->selectedItems();
-  KFileItem *tmp;
-  for (KFileItemListIterator it(*list); (tmp = it.current()); ++it)
+  const KFileItemList list = fileselector->dirOperator()->selectedItems();
+
+  foreach (const KFileItem tmp, list )
   {
-    m_viewManager->openUrl(tmp->url());
+    m_viewManager->openUrl(tmp.url());
     fileselector->dirOperator()->view()->setSelected(tmp, false);
   }
 }
@@ -725,7 +724,7 @@ void KateMainWindow::mSlotFixOpenWithMenu()
     KService::Ptr service = *it;
     if (service->name() == "Kate") continue;
     a = menu->addAction(KIcon(service->icon()), service->name());
-    a->setData(service->desktopEntryPath());
+    a->setData(service->entryPath());
   }
   // append "Other..." to call the KDE "open with" dialog.
   a = documentOpenWith->menu()->addAction(i18n("&Other..."));
@@ -878,18 +877,20 @@ void KateMainWindow::saveProperties(KConfigGroup& config)
       }
   }
 
+  fileOpenRecent->saveEntries( KConfigGroup(config.config(), "Recent Files" ) );
   m_viewManager->saveViewConfiguration (config);
 }
 
-void KateMainWindow::readProperties(const KConfigGroup& config)
+void KateMainWindow::readProperties(KConfigGroup config)
 {
-  startRestore(config.config(), config.group());
+  startRestore(config.config(), config.name());
 
   // perhaps enable plugin guis
   KatePluginManager::self()->enableAllPluginsGUI (this, config.config());
 
   finishRestore ();
 
+  fileOpenRecent->loadEntries( KConfigGroup(config.config(), "Recent Files" ) );
   m_viewManager->restoreViewConfiguration (config);
 }
 
@@ -929,4 +930,19 @@ void KateMainWindow::slotDocModified(KTextEditor::Document *document)
   if (document->isModified()) m_documentModel->modified(modelIndexForDocument(document));
 }
 
+void KateMainWindow::saveWindowConfig(const KConfigGroup &_config)
+{
+  KConfigGroup config( _config );
+  saveMainWindowSettings(config);
+  saveWindowSize(config);
+  config.writeEntry("WindowState", int(((KParts::MainWindow*)this)->windowState()));
+  config.sync();
+}
+
+void KateMainWindow::restoreWindowConfig(const KConfigGroup &config)
+{
+  applyMainWindowSettings(config);
+  restoreWindowSize(config);
+  setWindowState( QFlags<Qt::WindowState>(config.readEntry("WindowState", int(Qt::WindowActive))) );
+}
 // kate: space-indent on; indent-width 2; replace-tabs on;
