@@ -26,6 +26,7 @@
 #include <kactioncollection.h>
 #include <kactionmenu.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
@@ -255,13 +256,12 @@ namespace KateMDI
 //BEGIN SIDEBAR
 
   Sidebar::Sidebar (KMultiTabBar::KMultiTabBarPosition pos, MainWindow *mainwin, QWidget *parent)
-      : KMultiTabBar ((pos == KMultiTabBar::Top || pos == KMultiTabBar::Bottom) ? KMultiTabBar::Horizontal : KMultiTabBar::Vertical, parent)
+      : KMultiTabBar (pos, parent)
       , m_mainWin (mainwin)
       , m_splitter (0)
       , m_ownSplit (0)
       , m_lastSize (0)
   {
-    setPosition( pos );
     hide ();
   }
 
