@@ -143,7 +143,7 @@ bool KateSession::rename (const QString &name)
     m_sessionFileRel = oldRel;
     return false;
   }
-  KIO::CopyJob *job = KIO::move(KUrl(QString("file://") + oldSessionFile), KUrl(QString("file://") + sessionFile()), false);
+  KIO::CopyJob *job = KIO::move(KUrl(QString("file://") + oldSessionFile), KUrl(QString("file://") + sessionFile()), KIO::HideProgressInfo);
   if ( ! KIO::NetAccess::synchronousRun(job, 0) )
   {
     m_sessionFileRel = oldRel;
@@ -274,6 +274,7 @@ void KateSessionManager::activateSession (KateSession::Ptr session,
   {
     // open the new session
     KConfig *sc = activeSession()->configRead();
+    const bool loadDocs = (sc != 0); // do not load docs for new sessions
 
     // if we have no session config object, try to load the default
     // (anonymous/unnamed sessions)
@@ -283,7 +284,7 @@ void KateSessionManager::activateSession (KateSession::Ptr session,
     // load plugin config + plugins
     KatePluginManager::self()->loadConfig (sc);
 
-    if (sc)
+    if (sc && loadDocs)
       KateApp::self()->documentManager()->restoreDocumentList (sc);
 
     // window config
@@ -307,6 +308,8 @@ void KateSessionManager::activateSession (KateSession::Ptr session,
         {
           KateApp::self()->mainWindow(i)->readProperties(KConfigGroup(sc, QString ("MainWindow%1").arg(i) ));
         }
+
+        KateApp::self()->mainWindow(i)->restoreWindowConfig(KConfigGroup(sc, QString ("MainWindow%1 Settings").arg(i)));
       }
 
       // remove mainwindows we need no longer...
@@ -351,10 +354,13 @@ static void saveSessionTo(KConfig *sc)
   sc->group("Open MainWindows").writeEntry ("Count", KateApp::self()->mainWindows ());
 
   // save config for all windows around ;)
+  bool saveWindowConfig = KConfigGroup(KGlobal::config(), "General").readEntry("Restore Window Configuration", true);
   for (int i = 0; i < KateApp::self()->mainWindows (); ++i )
   {
     KConfigGroup cg(sc, QString ("MainWindow%1").arg(i) );
     KateApp::self()->mainWindow(i)->saveProperties (cg);
+    if (saveWindowConfig)
+      KateApp::self()->mainWindow(i)->saveWindowConfig(KConfigGroup(sc, QString ("MainWindow%1 Settings").arg(i)));
   }
 
   sc->sync();
@@ -432,6 +438,16 @@ bool KateSessionManager::chooseSession ()
   QString lastSession (c.readEntry ("Last Session", defaultSessionFile()));
   QString sesStart (c.readEntry ("Startup Session", "manual"));
 
+  // if this is the first time Kate App starts, create a i18ned default.katesession
+  bool firstStart = c.readEntry ("First Start", true);
+  if (firstStart) {
+    c.writeEntry ("First Start", false);
+    QFile::copy(defaultSessionFile(), sessionsDir() + "/default.katesession");
+    KateSession *ds = new KateSession(this, "default.katesession");
+    ds->rename(i18n("Default Session"));
+    delete ds;
+  }
+
   // uhh, just open last used session, show no chooser
   if (sesStart == "last")
   {
@@ -670,7 +686,8 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
   m_sessions->setHeaderLabels(header);
   m_sessions->setRootIsDecorated( false );
   m_sessions->setItemsExpandable( false );
-  m_sessions->setSelectionBehavior(QAbstractItemView::SelectItems);
+  m_sessions->setAllColumnsShowFocus( true );
+  m_sessions->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
   connect (m_sessions, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(selectionChanged(QTreeWidgetItem *, QTreeWidgetItem *)));
@@ -689,6 +706,8 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
       m_sessions->setCurrentItem (item);
   }
 
+  m_sessions->resizeColumnToContents(0);
+
   m_useLast = new QCheckBox (i18n ("&Always use this choice"), page);
   vb->addWidget(m_useLast);
 
@@ -783,7 +802,8 @@ KateSessionOpenDialog::KateSessionOpenDialog (QWidget *parent)
   m_sessions->setHeaderLabels(header);
   m_sessions->setRootIsDecorated( false );
   m_sessions->setItemsExpandable( false );
-  m_sessions->setSelectionBehavior(QAbstractItemView::SelectItems);
+  m_sessions->setAllColumnsShowFocus( true );
+  m_sessions->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
@@ -791,6 +811,7 @@ KateSessionOpenDialog::KateSessionOpenDialog (QWidget *parent)
   {
     new KateSessionChooserItem (m_sessions, slist[i]);
   }
+  m_sessions->resizeColumnToContents(0);
 
   setResult (resultCancel);
   connect(this, SIGNAL(user1Clicked()), this, SLOT(slotUser1()));
@@ -850,12 +871,15 @@ KateSessionManageDialog::KateSessionManageDialog (QWidget *parent)
   header << i18nc("The number of open documents", "Open Documents");
   m_sessions->setHeaderLabels(header);
   m_sessions->setRootIsDecorated( false );
+  m_sessions->setItemsExpandable( false );
+  m_sessions->setAllColumnsShowFocus( true );
   m_sessions->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
   connect (m_sessions, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(selectionChanged(QTreeWidgetItem *, QTreeWidgetItem *)));
 
   updateSessionList ();
+  m_sessions->resizeColumnToContents(0);
 
   QVBoxLayout *vb = new QVBoxLayout ();
   hb->addItem(vb);
