@@ -33,6 +33,7 @@
 #include <KMimeTypeChooser>
 #include <KXmlGuiWindow>
 #include <KConfig>
+#include <KConfigGroup>
 #include <KRun>
 #include <KIconDialog>
 #include <KMenu>
@@ -154,7 +155,7 @@ void KateExternalToolsCommand::reload ()
   m_map.clear();
   m_name.clear();
 
-  KConfig _config( "appdata", "externaltools", KConfig::NoGlobals  );
+  KConfig _config( "externaltools", KConfig::NoGlobals, "appdata" );
   KConfigGroup config(&_config, "Global");
   QStringList tools = config.readEntry("tools", QStringList());
 
@@ -488,7 +489,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
                          "The name will be displayed in the 'Tools->External' menu") );
 
   btnIcon = new KIconButton( w );
-  btnIcon->setIconSize( K3Icon::SizeSmall );
+  btnIcon->setIconSize( KIconLoader::SizeSmall );
   lo->addWidget( btnIcon, 1, 3 );
   if ( tool && !tool->icon.isEmpty() )
     btnIcon->setIcon( tool->icon );
@@ -655,7 +656,7 @@ KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( QWidget *parent, c
   lbTools->setWhatsThis(i18n(
                           "This list shows all the configured tools, represented by their menu text.") );
 
-  config = new KConfig("appdata", "externaltools", KConfig::NoGlobals );
+  config = new KConfig( "externaltools", KConfig::NoGlobals, "appdata" );
   reset();
   slotSelectionChanged();
 }
@@ -704,7 +705,7 @@ void KateExternalToolsConfigWidget::reset()
 
 QPixmap KateExternalToolsConfigWidget::blankIcon()
 {
-  QPixmap pm( K3Icon::SizeSmall, K3Icon::SizeSmall );
+  QPixmap pm( KIconLoader::SizeSmall, KIconLoader::SizeSmall );
   pm.fill();
   pm.setMask( pm.createHeuristicMask() );
   return pm;
