@@ -2,6 +2,7 @@
    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
    Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
+   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,13 +28,12 @@
 #include <khbox.h>
 #include <kvbox.h>
 #include <QLabel>
-#include <q3strlist.h>
 
 #include <QApplication>
 #include <QListWidget>
-#include <qscrollbar.h>
+#include <QScrollBar>
 #include <QSpinBox>
-#include <q3groupbox.h>
+#include <QGroupBox>
 #include <QCheckBox>
 #include <QRegExp>
 #include <QTimer>
@@ -81,7 +81,9 @@ KateFileSelectorPlugin::KateFileSelectorPlugin( QObject* parent, const QStringLi
 
 Kate::PluginView *KateFileSelectorPlugin::createView (Kate::MainWindow *mainWindow)
 {
-  return new KateFileSelectorPluginView (mainWindow);
+  KateFileSelectorPluginView* kateFileSelectorPluginView = new KateFileSelectorPluginView (mainWindow);
+  m_fileSelector = kateFileSelectorPluginView->kateFileSelector();
+  return kateFileSelectorPluginView;
 }
 
 KateFileSelectorPluginView::KateFileSelectorPluginView (Kate::MainWindow *mainWindow)
@@ -98,21 +100,26 @@ KateFileSelectorPluginView::~KateFileSelectorPluginView ()
   delete m_fileSelector->parentWidget();
 }
 
-void KateFileSelectorPluginView::readSessionConfig(KConfig* config, const QString& group)
+void KateFileSelectorPluginView::readSessionConfig(KConfigBase* config, const QString& group)
 {
-  m_fileSelector->readConfig(config, group);
+  m_fileSelector->readSessionConfig(config, group);
+}
+
+void KateFileSelectorPluginView::writeSessionConfig(KConfigBase* config, const QString& group)
+{
+  m_fileSelector->writeSessionConfig(config, group);
 }
 
 uint KateFileSelectorPlugin::configPages() const
 {
-  return 0;
+  return 1;
 }
 
 Kate::PluginConfigPage *KateFileSelectorPlugin::configPage (uint number, QWidget *parent, const char *name)
-{
-  if (number != 0) return 0;
-  //return new KFSConfigPage(parent,name,*(m_views.begin()));
-  return 0;
+{	
+  if (number != 0) 
+    return 0;
+  return new KFSConfigPage(parent, name, m_fileSelector);
 }
 
 QString KateFileSelectorPlugin::configPageName (uint number) const
@@ -148,30 +155,11 @@ KateFileSelectorToolBar::KateFileSelectorToolBar(QWidget *parent)
 
 KateFileSelectorToolBar::~KateFileSelectorToolBar()
 {}
-
-KateFileSelectorToolBarParent::KateFileSelectorToolBarParent(QWidget *parent)
-    : QFrame(parent), m_tb(0)
-{}
-KateFileSelectorToolBarParent::~KateFileSelectorToolBarParent()
-{}
-void KateFileSelectorToolBarParent::setToolBar(KateFileSelectorToolBar *tb)
-{
-  m_tb = tb;
-}
-
-void KateFileSelectorToolBarParent::resizeEvent ( QResizeEvent * )
-{
-  if (m_tb)
-  {
-    setMinimumHeight(m_tb->sizeHint().height());
-    m_tb->resize(width(), height());
-  }
-}
 //END
 
 //BEGIN Constructor/destructor
 
-::KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
+KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
                                       QWidget * parent, const char * name )
     : KVBox (parent),
     mainwin(mainWindow),
@@ -182,9 +170,7 @@ void KateFileSelectorToolBarParent::resizeEvent ( QResizeEvent * )
 
   QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
 
-  KateFileSelectorToolBarParent *tbp = new KateFileSelectorToolBarParent(this);
-  toolbar = new KateFileSelectorToolBar(tbp);
-  tbp->setToolBar(toolbar);
+  toolbar = new KateFileSelectorToolBar(this);
   toolbar->setMovable(false);
   qInstallMsgHandler( oldHandler );
 
@@ -199,9 +185,9 @@ void KateFileSelectorToolBarParent::resizeEvent ( QResizeEvent * )
 
   dir = new KDirOperator(KUrl(), this);
   dir->setView(KFile::/* Simple */Detail);
-  dir->view()->setSelectionMode(KFile::Extended);
-  connect ( dir, SIGNAL( viewChanged(KFileView *) ),
-           this, SLOT( selectorViewChanged(KFileView *) ) );
+  dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
+  connect ( dir, SIGNAL( viewChanged(QAbstractItemView *) ),
+           this, SLOT( selectorViewChanged(QAbstractItemView *) ) );
   setStretchFactor(dir, 2);
   dir->setSizePolicy (QSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
 
@@ -275,58 +261,63 @@ void KateFileSelectorToolBarParent::resizeEvent ( QResizeEvent * )
   btnFilter->setWhatsThis(        i18n("<p>This button clears the name filter when toggled off, or "
                                        "reapplies the last filter used when toggled on.</p>") );
 
-  connect(dir, SIGNAL(fileSelected(const KFileItem*)), this, SLOT(fileSelected(const KFileItem*)));
+  connect(dir, SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
+
+  readConfig();
 }
 
-::KateFileSelector::~KateFileSelector()
+KateFileSelector::~KateFileSelector()
 {}
 //END Constroctor/Destrctor
 
 //BEGIN Public Methods
 
-void ::KateFileSelector::readConfig(KConfig *config, const QString & name)
+void KateFileSelector::readConfig()
 {
-  kDebug() << "===================================================================::KateFileSelector::readConfig";
+
+//   dir->setView( KFile::Default );
+//   dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
+
+  // set up the toolbar
+  KConfigGroup fileselectorConfigGroup(KGlobal::config(), "fileselector");
+  setupToolbar( fileselectorConfigGroup.readEntry( "toolbar actions", QStringList(), ',' ) );
+
+  cmbPath->setMaxItems( fileselectorConfigGroup.readEntry( "pathcombo history len", 9 ) );
+  // if we restore history
+
+  filter->setMaxCount( fileselectorConfigGroup.readEntry( "filter history len", 9 ) );
+
+  autoSyncEvents = fileselectorConfigGroup.readEntry( "AutoSyncEvents", 0 );
+}
+
+void ::KateFileSelector::readSessionConfig(KConfigBase *config, const QString & name)
+{
+
   KConfigGroup cgView(config, name + ":view");
   dir->setViewConfig(cgView );
 
   KConfigGroup cgDir(config, name + ":dir");
   dir->readConfig(cgDir);
 
-  dir->setView( KFile::Default );
-  dir->view()->setSelectionMode(KFile::Extended);
-
   KConfigGroup cg (config, name );
-
-  // set up the toolbar
-  setupToolbar( cg.readEntry( "toolbar actions", QStringList(), ',' ) );
-
-  cmbPath->setMaxItems( cg.readEntry( "pathcombo history len", 9 ) );
   cmbPath->setUrls( cg.readPathListEntry( "dir history" ) );
-  // if we restore history
-  if ( cg.readEntry( "restore location", true) || qApp->isSessionRestored() )
+
+  KConfigGroup globalConfig( KGlobal::config(), "fileselector" );
+
+  if ( globalConfig.readEntry( "restore location", true) || qApp->isSessionRestored() )
   {
     QString loc( cg.readPathEntry( "location" ) );
     if ( ! loc.isEmpty() )
-    {
-//       waitingDir = loc;
-//       QTimer::singleShot(0, this, SLOT(initialDirChangeHack()));
       setDir( loc );
-    }
   }
 
-  // else is automatic, as cmpPath->setURL is called when a location is entered.
-
-  filter->setMaxCount( cg.readEntry( "filter history len", 9 ) );
   filter->setHistoryItems( cg.readEntry("filter history", QStringList()), true );
   lastFilter = cg.readEntry( "last filter" );
   QString flt("");
-  if ( cg.readEntry( "restore last filter", true ) || qApp->isSessionRestored() )
+  if ( globalConfig.readEntry( "restore last filter", true ) || qApp->isSessionRestored() )
     flt = cg.readEntry("current filter");
   filter->lineEdit()->setText( flt );
   slotFilterChange( flt );
-
-  autoSyncEvents = cg.readEntry( "AutoSyncEvents", 0 );
 }
 
 void ::KateFileSelector::initialDirChangeHack()
@@ -356,14 +347,22 @@ void ::KateFileSelector::setupToolbar( QStringList actions )
   }
 }
 
-void ::KateFileSelector::writeConfig(KConfig *config, const QString & name)
+void KateFileSelector::writeConfig()
+{
+  KConfigGroup cg = KConfigGroup( KGlobal::config(), "fileselector" );
+
+  cg.writeEntry( "pathcombo history len", cmbPath->maxItems() );
+  cg.writeEntry( "filter history len", filter->maxCount() );
+  cg.writeEntry( "filter history", filter->historyItems() );
+  cg.writeEntry( "AutoSyncEvents", autoSyncEvents );
+}
+
+void KateFileSelector::writeSessionConfig(KConfigBase *config, const QString & name)
 {
   KConfigGroup cgDir(config, name + ":dir");
   dir->writeConfig(cgDir);
 
   KConfigGroup cg = KConfigGroup( config, name );
-
-  cg.writeEntry( "pathcombo history len", cmbPath->maxItems() );
   QStringList l;
   for (int i = 0; i < cmbPath->count(); i++)
   {
@@ -371,18 +370,14 @@ void ::KateFileSelector::writeConfig(KConfig *config, const QString & name)
   }
   cg.writePathEntry( "dir history", l );
   cg.writePathEntry( "location", cmbPath->currentText() );
-
-  cg.writeEntry( "filter history len", filter->maxCount() );
-  cg.writeEntry( "filter history", filter->historyItems() );
   cg.writeEntry( "current filter", filter->currentText() );
   cg.writeEntry( "last filter", lastFilter );
-  cg.writeEntry( "AutoSyncEvents", autoSyncEvents );
 }
 
 void ::KateFileSelector::setView(KFile::FileView view)
 {
   dir->setView(view);
-  dir->view()->setSelectionMode(KFile::Extended);
+  dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
 }
 
 //END Public Methods
@@ -447,19 +442,16 @@ void ::KateFileSelector::setDir( KUrl u )
 
 //BEGIN Private Slots
 
-void ::KateFileSelector::fileSelected(const KFileItem * /*file*/)
+void ::KateFileSelector::fileSelected(const KFileItem & /*file*/)
 {
-  const KFileItemList *list = dir->selectedItems();
+  const KFileItemList list = dir->selectedItems();
 
-  KFileItem *tmp;
-  KFileItemList::const_iterator it = list->begin();
-  const KFileItemList::const_iterator end = list->end();
-  for ( ; it != end; ++it )
+  foreach (const KFileItem& item, list)
   {
-    tmp = (*it);
-    mainwin->openUrl(tmp->url());
-    dir->view()->setSelected(tmp, false);
+    mainwin->openUrl(item.url());
   }
+
+  dir->view()->selectionModel()->clear();
 }
 
 
@@ -549,9 +541,9 @@ void ::KateFileSelector::kateViewChanged()
   acSyncDir->setEnabled( ! activeDocumentUrl().directory().isEmpty() );
 }
 
-void ::KateFileSelector::selectorViewChanged( KFileView * newView )
+void ::KateFileSelector::selectorViewChanged( QAbstractItemView * newView )
 {
-  newView->setSelectionMode(KFile::Extended);
+  newView->setSelectionMode(QAbstractItemView::ExtendedSelection);
 }
 
 //END Private Slots
@@ -650,10 +642,15 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   lo->setSpacing( spacing );
 
   // Toolbar - a lot for a little...
-  Q3GroupBox *gbToolbar = new Q3GroupBox( 1, Qt::Vertical, i18n("Toolbar"), this );
+  QGroupBox *gbToolbar = new QGroupBox(i18n("Toolbar"), this );
   acSel = new KActionSelector( gbToolbar );
   acSel->setAvailableLabel( i18n("A&vailable actions:") );
   acSel->setSelectedLabel( i18n("S&elected actions:") );
+  
+  QVBoxLayout *vbox = new QVBoxLayout;
+  vbox->addWidget(acSel);
+  gbToolbar->setLayout(vbox);
+  
   lo->addWidget( gbToolbar );
   connect( acSel, SIGNAL( added( QListWidgetItem * ) ), this, SLOT( slotMyChanged() ) );
   connect( acSel, SIGNAL( removed( QListWidgetItem * ) ), this, SLOT( slotMyChanged() ) );
@@ -661,9 +658,15 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   connect( acSel, SIGNAL( movedDown( QListWidgetItem * ) ), this, SLOT( slotMyChanged() ) );
 
   // Sync
-  Q3GroupBox *gbSync = new Q3GroupBox( 1, Qt::Horizontal, i18n("Auto Synchronization"), this );
-  cbSyncActive = new QCheckBox( i18n("When a docu&ment becomes active"), gbSync );
-  cbSyncShow = new QCheckBox( i18n("When the file selector becomes visible"), gbSync );
+  QGroupBox *gbSync = new QGroupBox(i18n("Auto Synchronization"), this );
+  cbSyncActive = new QCheckBox( i18n("When a docu&ment becomes active"));
+  cbSyncShow = new QCheckBox( i18n("When the file selector becomes visible"));
+  
+  vbox = new QVBoxLayout;
+  vbox->addWidget(cbSyncActive);
+  vbox->addWidget(cbSyncShow);
+  gbSync->setLayout(vbox);
+  
   lo->addWidget( gbSync );
   connect( cbSyncActive, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
   connect( cbSyncShow, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
@@ -684,9 +687,15 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   connect( sbFilterHistLength, SIGNAL( valueChanged ( int ) ), this, SLOT( slotMyChanged() ) );
 
   // Session
-  Q3GroupBox *gbSession = new Q3GroupBox( 1, Qt::Horizontal, i18n("Session"), this );
-  cbSesLocation = new QCheckBox( i18n("Restore loca&tion"), gbSession );
-  cbSesFilter = new QCheckBox( i18n("Restore last f&ilter"), gbSession );
+  QGroupBox *gbSession = new QGroupBox(i18n("Session"), this );
+  cbSesLocation = new QCheckBox( i18n("Restore loca&tion"));
+  cbSesFilter = new QCheckBox( i18n("Restore last f&ilter"));
+  
+  vbox = new QVBoxLayout;
+  vbox->addWidget(cbSesLocation);
+  vbox->addWidget(cbSesFilter);
+  gbSession->setLayout(vbox);
+  
   lo->addWidget( gbSession );
   connect( cbSesLocation, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
   connect( cbSesFilter, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
@@ -751,14 +760,14 @@ void KFSConfigPage::apply()
   // toolbar
   QStringList l;
   ActionLBItem *aItem;
-  QList<QListWidgetItem *> list = acSel->selectedListWidget()->findItems(QString("*"), Qt::MatchRegExp);
+  QList<QListWidgetItem *> list = acSel->selectedListWidget()->findItems(QString("*"), Qt::MatchWildcard);
   foreach(QListWidgetItem *item, list)
   {
     aItem = (ActionLBItem*)item;
     l << aItem->idstring();
   }
   config.writeEntry( "toolbar actions", l );
-  fileSelector->setupToolbar( config.readEntry( "toolbar actions", QStringList(), ',' ) );
+  fileSelector->setupToolbar( l );
   // sync
   int s = 0;
   if ( cbSyncActive->isChecked() )
@@ -774,6 +783,8 @@ void KFSConfigPage::apply()
   //           as they are not needed during operation.
   config.writeEntry( "restore location", cbSesLocation->isChecked() );
   config.writeEntry( "restore last filter", cbSesFilter->isChecked() );
+
+  fileSelector->writeConfig();
 }
 
 void KFSConfigPage::reset()
