@@ -2,5 +2,5 @@
 $EXTRACTRC */*.kcfg >> rc.cpp || exit 11
 $EXTRACTRC gui/*.rc >> rc.cpp || exit 12
 $EXTRACTRC gui/*.ui >> rc.cpp || exit 13
-$XGETTEXT *.cpp */*.cpp -o $podir/kbugbuster.pot
+$XGETTEXT *.cpp backend/*.cpp -o $podir/kbugbuster.pot
 rm -f rc.cpp
