@@ -391,44 +391,19 @@ void TopLevel::createDocks()
                    "the top function in the current loaded dump.</li></ul></p>"));
 #endif
 
-  // Restore QT Dock positions...
-  KConfigGroup dockConfig(KGlobal::config(), QByteArray("Docks"));
-  QString str = dockConfig.readEntry("Position", QString());
-  if (0) qDebug("Docks/Position: '%s'", str.ascii());
-  if (str.isEmpty()) {
-    // default positions
-    addDockWidget( Qt::LeftDockWidgetArea, _partDock );
-    addDockWidget( Qt::LeftDockWidgetArea, _stackDock );
-    addDockWidget( Qt::LeftDockWidgetArea, _functionDock );
-    _stackDock->hide();
+	// default positions, will be adjusted automatically by stored state in config
+	addDockWidget(Qt::LeftDockWidgetArea, _partDock );
+	addDockWidget(Qt::LeftDockWidgetArea, _stackDock );
+	addDockWidget(Qt::LeftDockWidgetArea, _functionDock );
+	_stackDock->hide();
+
 #if ENABLE_DUMPDOCK
-    addDockWidget( Qt::LeftDockWidgetArea, _dumpDock );
-    _dumpDock->hide();
+	addDockWidget( Qt::LeftDockWidgetArea, _dumpDock );
+	_dumpDock->hide();
 #endif
-  }
-  else {
-#ifdef __GNUC__
-#warning port to Qt4
-#endif
-#if 0
-    QTextStream ts( &str, QIODevice::ReadOnly );
-    ts >> *this;
-#endif
-  }
 
-  _forcePartDock = dockConfig.readEntry("ForcePartDockVisible", false);
-
-
-#if 0
-  // dock context menu
-  setAppropriate(_partDock, true);
-  setAppropriate(_stackDock, true);
-  setAppropriate(_dumpDock, true);
-  setAppropriate(_functionDock, true);
-
-  connect( _partDock, SIGNAL(contextMenuRequested(const QPoint &)),
-           this, SLOT(showDockMenu(const QPoint &)));
-#endif
+	KConfigGroup dockConfig(KGlobal::config(), QByteArray("Docks"));
+	_forcePartDock = dockConfig.readEntry("ForcePartDockVisible", false);
 }
 
 
@@ -1975,38 +1950,15 @@ bool TopLevel::queryExit()
 
     saveCurrentState(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
 
-  // save QT dock positions...
-
-  // We don't want to save the KToolbar position here.
-  // Its already stored.
-  delete toolBar();
-#ifdef __GNUC__
-#warning port to Qt4
-#endif
-#if 0
-  KConfigGroup dockConfig(KGlobal::config(), QByteArray("Docks"));
-  QString str;
-  QTextStream ts( &str, QIODevice::WriteOnly );
-  ts << *this;
-#if 1
-  dockConfig.writeEntry("Position", str);
-#else
-  /* We store this with a localized key because for dock positions,
-   * QT uses the localized captions of docks.
-   * This way, when changing languages, you don't loose dock position
-   * settings.
-   * For the retrieval to work, we need to store a non-localized.
-   */
-  dockConfig.writeEntry("Position", str, true, KConfigBase::Global);
-#endif
+  // toolbar and dock positions are automatically stored
 
   // if part dock was chosen visible even for only 1 part loaded,
   // keep this choice...
   _forcePartDock = false;
   if (_data && (_data->parts().count()<2) && _partDock->isVisible())
     _forcePartDock=true;
+  KConfigGroup dockConfig(KGlobal::config(), QByteArray("Docks"));
   dockConfig.writeEntry("ForcePartDockVisible", _forcePartDock);
-#endif
 
   return true;
 }
@@ -2341,59 +2293,65 @@ void TopLevel::upTriggered(QAction* action)
 
 void TopLevel::showMessage(const QString& msg, int ms)
 {
-  if (_statusbar)
-    _statusbar->message(msg, ms);
+	if (_statusbar)
+		_statusbar->message(msg, ms);
 }
 
 void TopLevel::showStatus(QString msg, int progress)
 {
-    static bool msgUpdateNeeded = true;
+	static bool msgUpdateNeeded = true;
 
-    if (msg.isEmpty()) {
-	if (_progressBar) {
-	    _statusbar->removeWidget(_progressBar);
-	    delete _progressBar;
-	    _progressBar = 0;
+	if (msg.isEmpty()) {
+		if (_progressBar) {
+			_statusbar->removeWidget(_progressBar);
+			delete _progressBar;
+			_progressBar = 0;
+		}
+		_statusbar->clear();
+		_progressMsg = msg;
+		return;
 	}
-	_statusbar->clear();
-	_progressMsg = msg;
-	return;
-    }
 
-    if (_progressMsg.isEmpty())	_progressStart.start();
+	if (_progressMsg.isEmpty())
+		_progressStart.start();
 
-    if (msg != _progressMsg) {
-	_progressMsg = msg;
-	msgUpdateNeeded = true;
-    }
+	if (msg != _progressMsg) {
+		_progressMsg = msg;
+		msgUpdateNeeded = true;
+	}
 
-    // do nothing if last change was less than 0.5 seconds ago
-    if (_progressStart.elapsed() < 500) return;
+	// do nothing if last change was less than 0.5 seconds ago
+	if (_progressStart.elapsed() < 500)
+		return;
 
-    if (!_progressBar) {
-	_progressBar = new QProgressBar(_statusbar);
-	_progressBar->setMaximumSize(200, _statusbar->height()-4);
-	_statusbar->addWidget(_progressBar, 1, true);
-	_progressBar->show();
-	msgUpdateNeeded = true;
-    }
+	if (!_progressBar) {
+		_progressBar = new QProgressBar(_statusbar);
+		_progressBar->setMaximumSize(200, _statusbar->height()-4);
+		_statusbar->addWidget(_progressBar, 1, true);
+		_progressBar->show();
+		msgUpdateNeeded = true;
+	}
 
-    _progressStart.restart();
+	_progressStart.restart();
 
-    if (msgUpdateNeeded) {
-	_statusbar->message(msg);
-	msgUpdateNeeded = false;
-    }
-    _progressBar->setValue(progress);
+	if (msgUpdateNeeded) {
+		_statusbar->message(msg);
+		msgUpdateNeeded = false;
+	}
+	_progressBar->setValue(progress);
 
-    // let the progress bar update itself
-#if 0
-    QEventLoop* l = qApp->eventLoop();
-    if (l) l->processEvents(QEventLoop::ExcludeUserInput);
-#else
-    // for Qt 3.0.x. This allows user input and thus potentially races
-    qApp->processEvents();
-#endif
+	// let the progress bar update itself
+	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+}
+
+void TopLevel::showLoadError(QString name, int line, QString msg)
+{
+	kError() << "Loading" << name.ascii() << ":" << line << ": " << msg.ascii();
+}
+
+void TopLevel::showLoadWarning(QString name, int line, QString msg)
+{
+	kWarning() << "Loading" << name.ascii() << ":" << line << ": " << msg.ascii();
 }
 
 #include "toplevel.moc"
