@@ -116,9 +116,9 @@ sub processFile() {
                           '^[[:space:]]*[Qq][Tt]4_[Aa][Uu][Tt][Oo][Mm][Oo][Cc]',
                           'No need for QT4_AUTOMOC(). Remove it.');
 
-    $issues += &checkLine($line,$linecnt,
-			  '[Kk][Dd][Ee]3_[Aa][Dd][Dd]_[Kk][Pp][Aa][Rr][Tt]',
-			  'Use KDE4_ADD_PLUGIN() instead of KDE3_ADD_KPART()');
+    #$issues += &checkLine($line,$linecnt,
+    #			  '[Kk][Dd][Ee]3_[Aa][Dd][Dd]_[Kk][Pp][Aa][Rr][Tt]',
+    #			  'Use KDE4_ADD_PLUGIN() instead of KDE3_ADD_KPART()');
 
     $issues += &checkLine($line,$linecnt,
 			  '^[[:space:]]*[Aa][Dd][Dd]_[Ll][Ii][Bb][Rr][Aa][Rr][Yy]',
@@ -241,6 +241,32 @@ sub processFile() {
                    'set_target_properties.*PROPERTIES.*[[:space:]]SOVERSION[[:space:]][[:digit:]]',
                    'replace a hard-coded SOVERSION with "${GENERIC_LIB_SOVERSION}"');
 
+    #Qt variable
+    $issues +=
+      &checkLine($line,$linecnt,
+                 'target_link_libraries.*[[:space:]]QtDBus[\s/)]',
+                 'replace "QtDBus" with "${QT_QTDBUS_LIBRARY}"');
+
+    $issues +=
+      &checkLine($line,$linecnt,
+                 'target_link_libraries.*[[:space:]]Qt3Support[\s/)]',
+                 'replace "Qt3Support" with "${QT_QT3SUPPORT_LIBRARY}"');
+
+    $issues +=
+      &checkLine($line,$linecnt,
+                 'target_link_libraries.*[[:space:]]QtGui[\s/)]',
+                 'replace "QtGui" with "${QT_QTGUI_LIBRARY}"');
+
+    $issues +=
+      &checkLine($line,$linecnt,
+                 'target_link_libraries.*[[:space:]]QtNetwork[\s/)]',
+                 'replace "QtNetwork" with "${QT_QTNETWORK_LIBRARY}"');
+
+    $issues +=
+      &checkLine($line,$linecnt,
+                 'target_link_libraries.*[[:space:]]QtCore[\s/)]',
+                 'replace "QtCore" with "${QT_QTCORE_LIBRARY}"');
+
     # kdelibs variables
     if (! $in_kdelibs) {
       $issues +=
@@ -252,10 +278,6 @@ sub processFile() {
 		   'target_link_libraries.*[[:space:]]kio[\s/)]',
 		   'replace "kio" with "${KDE4_KIO_LIBS}"');
       $issues +=
-	&checkLine($line,$linecnt,
-		   'target_link_libraries.*[[:space:]]kdefx[\s/)]',
-		   'replace "kdefx" with "${KDE4_KDEFX_LIBS}"');
-      $issues +=
     &checkLine($line,$linecnt,
             'target_link_libraries.*[[:space:]]kdeprint[\s/)]',
             'replace "kdeprint" with "${KDE4_KDEPRINT_LIBS}"');
