@@ -287,7 +287,7 @@ while ($file = <$F>) {
     s!KGlobal::iconLoader!KIconLoader::global!;
     s!KGlobal::instance\(\)->iconLoader!KIconLoader::global!;
 
-    s!KIcon::NoGroup!K3Icon::NoGroup!g;
+    s!KIcon::NoGroup!KIconLoader::NoGroup!g;
 
     if ( /KApplication::ShutdownType|KApplication::ShutdownTypeHalt|KApplication::ShutdownMode|KApplication::ShutdownTypeReboot|KApplication::ShutdownTypeNone/ ) {
         push(@necessaryIncludes, "kworkspace.h");
@@ -474,16 +474,16 @@ while ($file = <$F>) {
         push(@necessaryIncludes, "kglobal.h");
     }
     if ( /kapp->miniIcon/ ) {
-        s!kapp->miniIcon\s*\(\s*\)!qApp->windowIcon().pixmap(IconSize(K3Icon::Small),IconSize(K3Icon::Small))!;
+        s!kapp->miniIcon\s*\(\s*\)!qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small))!;
         push(@necessaryIncludes, "kiconloader.h");
     }
 
     if ( /kapp->icon/ ) {
-	s!kapp->icon\s*\(\s*\)!qApp->windowIcon().pixmap(IconSize(K3Icon::Desktop),IconSize(K3Icon::Desktop))!;
+	s!kapp->icon\s*\(\s*\)!qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop))!;
 	push(@necessaryIncludes, "kiconloader.h");
     }
     if ( /app.icon/ ) {
-	s!app.icon\s*\(\s*\)!qApp.windowIcon().pixmap(IconSize(K3Icon::Desktop),IconSize(K3Icon::Desktop))!;
+	s!app.icon\s*\(\s*\)!qApp.windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop))!;
 	push(@necessaryIncludes, "kiconloader.h");
     }
 
@@ -547,9 +547,25 @@ while ($file = <$F>) {
     s!KFileDialog::getSaveURL!KFileDialog::getSaveUrl!;
     s!KFileDialog::getExistingURL!KFileDialog::getExistingUrl!;
     s!KIO::convertSizeFromKB!KIO::convertSizeFromKiB!;
-    s!KMimeType::iconForURL!KMimeType::iconNameForURL!;
+    s!KMimeType::iconForURL!KMimeType::iconNameForUrl!;
+    s!KMimeType::findByURL!KMimeType::findByUrl!;
     s!const\s+KFileItem\s\*\s*!const KFileItem& !g if (/gotPreview/ || /slotGotPreview/ || /slotPreview/); # KIO::PreviewJob
 
+    # KIO Job API changes
+    s/, ?false, ?false/, KIO::HideProgressInfo/ if (/KIO::del/);
+    s/, ?false, ?false/, KIO::NoReload, KIO::HideProgressInfo/ if (/KIO::get/ || /KIO::storedGet/);
+    s/, ?true, ?false/, KIO::Reload, KIO::HideProgressInfo/ if (/KIO::get/ || /KIO::storedGet/);
+    s/, ?false, ?true// if (/KIO::get/ || /KIO::storedGet/);
+    s/, ?false/, KIO::HideProgressInfo/ if (/KIO::file_delete/ || /KIO::stat/);
+    s/, ?false/, KIO::HideProgressInfo/ if (/KIO::special/ || /KIO::http_post/ || /KIO::rename/ || /KIO::move/);
+    s/, ?true// if (/KIO::special/);
+    s/, ?false, ?false/, KIO::HideProgressInfo, false/ if (/KIO::listDir/);
+    s/, ?false, ?true/, KIO::HideProgressInfo, true/ if (/KIO::listDir/);
+    s/, ?false, ?false, ?false/, KIO::HideProgressInfo/ if (/KIO::storedPut/);
+    s/, ?true, ?false, ?false/, KIO::Overwrite | KIO::HideProgressInfo/ if (/KIO::file_copy/ || /KIO::file_move/);
+    s/, ?true, ?false, ?true/, KIO::Overwrite/ if (/KIO::file_copy/ || /KIO::file_move/);
+    s/, ?false, ?false, ?false/, KIO::HideProgressInfo/ if (/KIO::file_copy/ || /KIO::file_move/);
+
     $_="" if (/include <kipc.h>/);
     s/KIPC::sendMessageAll/KGlobalSettings::self()->emitChange/;
     s/KIPC::/KGlobalSettings::/;
