@@ -5,7 +5,7 @@
  *  source code is not replicated in the XMI file.                         *
  *                                                                         *
  *  copyright       : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov     *
- *  (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>    *
+ *  (C) 2004-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>    *
  *                                                                         *
  ***************************************************************************
  *                                                                         *
@@ -78,7 +78,7 @@ void CppWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kDebug() << "Cannot write class of NULL concept!\n";
+        uDebug() << "Cannot write class of NULL concept!\n";
         return;
     }
 
@@ -92,7 +92,7 @@ void CppWriter::writeClass(UMLClassifier *c)
     }
 
     // preparations
-    m_classifierInfo = new ClassifierInfo(c, m_doc);
+    m_classifierInfo = new ClassifierInfo(c);
     m_classifierInfo->fileName = fileName;
     m_classifierInfo->className = cleanName(c->getName());
 
@@ -142,12 +142,12 @@ void CppWriter::writeHeaderFile (UMLClassifier *c, QFile &fileh) {
     QString str = getHeadingFile(".h");
     if(!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),m_classifierInfo->fileName + ".h");
-        str.replace(QRegExp("%filepath%"),fileh.name());
+        str.replace(QRegExp("%filepath%"),fileh.fileName());
         h << str<< m_endl;
     }
 
     // Write the hash define stuff to prevent multiple parsing/inclusion of header
-    QString hashDefine = m_classifierInfo->className.upper().simplified().replace(QRegExp(" "),  "_");
+    QString hashDefine = m_classifierInfo->className.toUpper().simplified().replace(QRegExp(" "),  "_");
     writeBlankLine(h);
     h << "#ifndef "<< hashDefine + "_H" << m_endl;
     h << "#define "<< hashDefine + "_H" << m_endl;
@@ -207,7 +207,7 @@ void CppWriter::writeSourceFile (UMLClassifier *c, QFile &filecpp ) {
     str = getHeadingFile(".cpp");
     if(!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),m_classifierInfo->fileName + ".cpp");
-        str.replace(QRegExp("%filepath%"),filecpp.name());
+        str.replace(QRegExp("%filepath%"),filecpp.fileName());
         cpp << str << m_endl;
     }
 
@@ -624,7 +624,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList *attribs,
         // from what I can tell, this IS the default behavior for
         // cleanName. I dunno why its not working -b.t.
         methodBaseName = methodBaseName.trimmed();
-        methodBaseName.replace(0,1,methodBaseName.at(0).upper());
+        methodBaseName.replace(0,1,methodBaseName.at(0).toUpper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(), varName,
                                             methodBaseName, at->getDoc(), Uml::chg_Changeable, isHeaderMethod,
@@ -640,7 +640,7 @@ void CppWriter::writeComment(const QString &comment, const QString &myIndent, QT
     // need to resolve for using with MAC/WinDoze eventually I assume
     if (comment.contains(QRegExp("\n"))) {
 
-        QStringList lines = QStringList::split( "\n", comment);
+        QStringList lines = comment.split( "\n" );
         for (int i= 0; i < lines.count(); i++)
         {
             cpp << myIndent << "// " << lines[i] << m_endl;
@@ -664,7 +664,7 @@ void CppWriter::writeDocumentation(QString header, QString body, QString end, QT
         cpp << formatDoc(body, indent + " * ");
     if (!end.isEmpty())
     {
-        QStringList lines = QStringList::split( "\n", end);
+        QStringList lines = end.split( "\n" );
         for (int i= 0; i < lines.count(); i++)
             cpp << formatDoc(lines[i], indent + " * ");
     }
@@ -735,11 +735,11 @@ void CppWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleNam
     // multiplicity object that we don't have to figure out what it means via regex.
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.lower();
+        QString fieldVarName = "m_" + roleName.toLower();
 
         // record this for later consideration of initialization IF the
         // multi value requires 1 of these objects
-        if(ObjectFieldVariables.findIndex(fieldVarName) == -1 &&
+        if(ObjectFieldVariables.indexOf(fieldVarName) == -1 &&
                 multi.contains(QRegExp("^1$"))
           )
         {
@@ -752,11 +752,11 @@ void CppWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleNam
     }
     else
     {
-        QString fieldVarName = "m_" + roleName.lower() + "Vector";
+        QString fieldVarName = "m_" + roleName.toLower() + "Vector";
 
         // record unique occurrences for later when we want to check
         // for initialization of this vector
-        if(VectorFieldVariables.findIndex(fieldVarName) == -1)
+        if(VectorFieldVariables.indexOf(fieldVarName) == -1)
             VectorFieldVariables.append(fieldVarName);
 
         stream << indent << policyExt()->getVectorClassName() <<"<" << fieldClassName << "*";
@@ -822,13 +822,13 @@ void CppWriter::writeAssociationRoleMethod (const QString &fieldClassName,
 {
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.lower();
+        QString fieldVarName = "m_" + roleName.toLower();
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, change, isHeaderMethod, false, writeMethodBody, stream);
     }
     else
     {
-        QString fieldVarName = "m_" + roleName.lower() + "Vector";
+        QString fieldVarName = "m_" + roleName.toLower() + "Vector";
         writeVectorAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, change, isHeaderMethod, writeMethodBody, stream);
     }
@@ -1018,8 +1018,8 @@ void CppWriter::writeInitAttibuteMethod (QTextStream &stream)
 
     m_indentLevel++;
     // first, initiation of fields derived from attributes
-    UMLAttributeList* atl = m_classifierInfo->getAttList();
-    foreach (UMLAttribute* at, *atl ) {
+    UMLAttributeList atl = m_classifierInfo->getAttList();
+    foreach (UMLAttribute* at, atl ) {
         if(!at->getInitialValue().isEmpty()) {
             QString varName = getAttributeVariableName(at);
             stream << getIndent() << varName << " = " << at->getInitialValue() << ";" << m_endl;
@@ -1259,7 +1259,7 @@ void CppWriter::printTextAsSeparateLinesWithIndent (const QString &text, const Q
     if(text.isEmpty())
         return;
 
-    QStringList lines = QStringList::split( "\n", text);
+    QStringList lines = text.split( "\n" );
     for (int i= 0; i < lines.count(); i++)
         stream << indent << lines[i] << m_endl;
 }
