@@ -141,7 +141,7 @@ QStringList CSharpWriter::defaultDatatypes() {
 
 void CSharpWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kDebug()<<"Cannot write class of NULL concept!";
+        uDebug()<<"Cannot write class of NULL concept!";
         return;
     }
 
@@ -605,7 +605,7 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
 
         UMLObject *o = a->getObject(Uml::B);
         if (o == NULL) {
-            kError() << "composition role B object is NULL" << endl;
+            uError() << "composition role B object is NULL" << endl;
             continue;
         }
         // Take name and documentaton from Role, take type name from the referenced object
@@ -628,7 +628,14 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
     }
 }
 
-void CSharpWriter::writeAttribute(QString doc, Uml::Visibility visibility, bool isStatic, QString typeName, QString name, QString initialValue, bool asProperty, QTextStream &cs) {
+void CSharpWriter::writeAttribute(const QString& doc,
+                                  Uml::Visibility visibility,
+                                  bool isStatic,
+                                  const QString& typeName,
+                                  const QString& name,
+                                  const QString& initialValue,
+                                  bool asProperty,
+                                  QTextStream &cs) {
 
     if (forceDoc() || !doc.isEmpty()) {
 
