@@ -31,6 +31,7 @@
 #include "dcodecomment.h"
 #include "dclassdeclarationblock.h"
 #include "dcodeclassfielddeclarationblock.h"
+#include "codegen_utils.h"
 #include "../classifier.h"
 #include "../codegenerationpolicy.h"
 #include "../uml.h"
@@ -88,7 +89,7 @@ QString DClassifierCodeDocument::getPath ( )
     path.replace(QRegExp("\\."),"/");
     path.replace(QRegExp("::"), "/");
 
-    path.lower();
+    path = path.toLower();
 
     return path;
 
@@ -98,13 +99,8 @@ QString DClassifierCodeDocument::getPath ( )
 // Other methods
 //
 
-QString DClassifierCodeDocument::capitalizeFirstLetter(const QString &string)
-{
-    return DCodeGenerator::capitalizeFirstLetter(string);
-}
-
 QString DClassifierCodeDocument::getDClassName (const QString &name) {
-    return capitalizeFirstLetter(CodeGenerator::cleanName(name));
+    return Codegen_Utils::capitalizeFirstLetter(CodeGenerator::cleanName(name));
 }
 
 // Initialize this d classifier code document
@@ -167,7 +163,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                     block->loadFromXMI(element);
                     if(!addTextBlock(block))
                     {
-                        kError()<<"loadFromXMI : unable to add codeComment to :"<<this<<endl;
+                        uError()<<"loadFromXMI : unable to add codeComment to :"<<this<<endl;
                         block->deleteLater();
                     } else
                         loadCheckForChildrenOK= true;
@@ -180,7 +176,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                         TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                         if(!tb || !addTextBlock(tb))
                         {
-                            kError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this<<endl;
+                            uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this<<endl;
                             // DON'T delete
                         } else
                             loadCheckForChildrenOK= true;
@@ -191,7 +187,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                             block->loadFromXMI(element);
                             if(!addTextBlock(block))
                             {
-                                kError()<<"loadFromXMI : unable to add codeBlock to :"<<this<<endl;
+                                uError()<<"loadFromXMI : unable to add codeBlock to :"<<this<<endl;
                                 block->deleteLater();
                             } else
                                 loadCheckForChildrenOK= true;
@@ -201,7 +197,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                                 block->loadFromXMI(element);
                                 if(!addTextBlock(block))
                                 {
-                                    kError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this<<endl;
+                                    uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this<<endl;
                                     block->deleteLater();
                                 } else
                                     loadCheckForChildrenOK= true;
@@ -214,7 +210,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                                         block->loadFromXMI(element);
                                         if(!addTextBlock(block))
                                         {
-                                            kError()<<"Unable to add hierarchicalcodeBlock to:"<<this<<endl;
+                                            uError()<<"Unable to add hierarchicalcodeBlock to:"<<this<<endl;
                                             block->deleteLater();
                                         } else
                                             loadCheckForChildrenOK= true;
@@ -231,11 +227,11 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                                                     loadCheckForChildrenOK= true;
                                                 else
                                                 {
-                                                    kError()<<"Unable to add codeoperation to:"<<this<<endl;
+                                                    uError()<<"Unable to add codeoperation to:"<<this<<endl;
                                                     block->deleteLater();
                                                 }
                                             } else
-                                                kError()<<"Unable to find operation create codeoperation for:"<<this<<endl;
+                                                uError()<<"Unable to find operation create codeoperation for:"<<this<<endl;
                                         } else
                                             if( name == "dclassdeclarationblock" )
                                             {
@@ -243,7 +239,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                                                 block->loadFromXMI(element);
                                                 if(!addTextBlock(block))
                                                 {
-                                                    kError()<<"Unable to add d code declaration block to:"<<this<<endl;
+                                                    uError()<<"Unable to add d code declaration block to:"<<this<<endl;
                                                     // DON'T delete.
                                                     // block->deleteLater();
                                                 } else
@@ -252,7 +248,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                 // This last item is only needed for extreme debugging conditions
                 // (E.g. making new codeclassdocument loader)
                 // else
-                //        kDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning";
+                //        uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning";
 
                 node = element.nextSibling();
                 element = node.toElement();
@@ -269,44 +265,25 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
         CodeDocument * test = dynamic_cast<CodeDocument*>(this);
         if(test)
         {
-            kWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
+            uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
         } else {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
             if(hb)
-                kWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
+                uWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
             else
-                kDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
+                uDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
         }
     }
 
 
 }
 
-QString DClassifierCodeDocument::scopeToDDecl(Uml::Visibility scope)
-{
-    QString scopeString;
-    switch(scope)
-    {
-      case Uml::Visibility::Public:
-        scopeString = "public";
-        break;
-      case Uml::Visibility::Protected:
-        scopeString = "protected";
-        break;
-      case Uml::Visibility::Private:
-      case Uml::Visibility::Implementation:
-          default:
-        scopeString = "private";
-        break;
-    }
-    return scopeString;
-}
-
 DClassDeclarationBlock * DClassifierCodeDocument::getClassDecl()
 {
     if(!classDeclCodeBlock)
     {
         classDeclCodeBlock = new DClassDeclarationBlock (this);
+        classDeclCodeBlock->updateContent();
         classDeclCodeBlock->setTag("ClassDeclBlock");
     }
     return classDeclCodeBlock;
