@@ -85,13 +85,13 @@ void DWriter::writeModuleImports(UMLClassifier *c, QTextStream &d) {
 
 void DWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kDebug()<<"Cannot write class of NULL concept!\n";
+        uDebug()<<"Cannot write class of NULL concept!\n";
         return;
     }
 
     isInterface = c->isInterface();
 
-    QString fileName = cleanName(c->getName().lower());
+    QString fileName = cleanName(c->getName().toLower());
 
     //find an appropriate name for our file
     fileName = findFileName(c, ".d");
@@ -115,7 +115,7 @@ void DWriter::writeClass(UMLClassifier *c) {
     str = getHeadingFile(".d");
     if(!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),fileName);
-        str.replace(QRegExp("%filepath%"),file.name());
+        str.replace(QRegExp("%filepath%"),file.fileName());
         d<<str<<m_endl;
     }
 
@@ -361,7 +361,7 @@ void DWriter::writeClassDecl(UMLClassifier *c, QTextStream &d) {
 }
 
 void DWriter::writeProtectionMod(Uml::Visibility visibility, QTextStream &d) {
-    d << m_indentation << scopeToDDecl(visibility) << ":" << m_endl << m_endl;
+    d << m_indentation << visibility.toString() << ":" << m_endl << m_endl;
 }
 
 void DWriter::writeAttributeDecl(Uml::Visibility visibility, UMLAttributeList &atlist, QTextStream &d) {
@@ -427,7 +427,7 @@ void DWriter::writeComment(const QString &comment, const QString &myIndent,
         d << myIndent << "/**" << m_endl;
     }
 
-    QStringList lines = QStringList::split("\n", comment);
+    QStringList lines = comment.split("\n" );
 
     if (lines.count() == 0) lines << comment;
 
@@ -461,7 +461,7 @@ void DWriter::writeDocumentation(QString header, QString body, QString end, QStr
         d << formatDoc(body, indent+" * ");
     if (!end.isEmpty())
     {
-        QStringList lines = QStringList::split( "\n", end);
+        QStringList lines = end.split( "\n" );
         for (int i= 0; i < lines.count(); i++)
             d << formatDoc(lines[i], indent + " * ");
     }
@@ -899,7 +899,8 @@ void DWriter::writeOperations(UMLOperationList &oplist, QTextStream &d) {
     }
 }
 
-QString DWriter::fixInitialStringDeclValue(QString value, QString type) {
+QString DWriter::fixInitialStringDeclValue(const QString& val, const QString& type) {
+    QString value = val;
     // check for strings only
     if (!value.isEmpty() && type == "String") {
         if (!value.startsWith('"'))
@@ -910,34 +911,22 @@ QString DWriter::fixInitialStringDeclValue(QString value, QString type) {
     return value;
 }
 
-QString DWriter::scopeToDDecl(Uml::Visibility scope) {
-    QString scopeString;
-
-    switch(scope) {
-        case Uml::Visibility::Public: scopeString = "public"; break;
-        case Uml::Visibility::Protected: scopeString = "protected"; break;
-        case Uml::Visibility::Private: scopeString = "private"; break;
-        default: break; //TODO: package and export
-    }
-
-    return scopeString;
-}
-
 // methods like this _shouldn't_ be needed IF we properly did things thruought the code.
 QString DWriter::getUMLObjectName(UMLObject *obj) {
     return(obj!=0)?obj->getName():QString("NULL");
 }
 
-QString DWriter::deCapitaliseFirstLetter(QString string) {
-    string.replace( 0, 1, string[0].lower());
+QString DWriter::deCapitaliseFirstLetter(const QString& str) {
+    QString string = str;
+    string.replace( 0, 1, string[0].toLower());
     return string;
 }
 
-QString DWriter::pluralize(QString string) {
+QString DWriter::pluralize(const QString& string) {
     return string + (string.right(1) == "s" ? "es" : "s");
 }
 
-QString DWriter::unPluralize(QString string) {
+QString DWriter::unPluralize(const QString& string) {
     // does not handle special cases liek datum -> data, etc.
 
     if (string.count() > 2 && string.right(3) == "ses") {
