@@ -5,7 +5,7 @@
     source code is not replicated in the XMI file.
                              -------------------
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
+      (C) 2004-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
 ***************************************************************************/
 
 /***************************************************************************
@@ -49,13 +49,13 @@ void JavaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kDebug()<<"Cannot write class of NULL concept!\n";
+        uDebug()<<"Cannot write class of NULL concept!\n";
         return;
     }
 
     isInterface = c->isInterface();
 
-    QString fileName = cleanName(c->getName().lower());
+    QString fileName = cleanName(c->getName().toLower());
 
     //find an appropriate name for our file
     fileName = findFileName(c,".java");
@@ -132,7 +132,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
     str = getHeadingFile(".java");
     if(!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),fileName);
-        str.replace(QRegExp("%filepath%"),file.name());
+        str.replace(QRegExp("%filepath%"),file.fileName());
         java<<str<<m_endl;
     }
 
@@ -271,7 +271,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     }
 
     // Now write the actual class declaration
-    QString scope = ""; // = scopeToJavaDecl(c->getVisibility());
+    QString scope = ""; // = c->getVisibility().toString();
     if (c->getVisibility() != Uml::Visibility::Public) {
         // We should emit a warning in here .. java doesn't like to allow
         // private/protected classes. The best we can do (I believe)
@@ -395,7 +395,7 @@ void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility
         // force capitalizing the field name, this is silly,
         // from what I can tell, this IS the default behavior for
         // cleanName. I dunno why its not working -b.t.
-        fieldName.replace(0,1,fieldName.at(0).upper());
+        fieldName.replace(0,1,fieldName.at(0).toUpper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(),
                                             cleanName(at->getName()),
@@ -416,7 +416,7 @@ void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
 
         if(javaDocStyle)
             java << myIndent << "/**" << m_endl;
-        QStringList lines = QStringList::split( "\n", comment);
+        QStringList lines = comment.split( "\n" );
         for (int i= 0; i < lines.count(); i++)
         {
             writeBlankLine(java);
@@ -453,7 +453,7 @@ void JavaWriter::writeDocumentation(QString header, QString body, QString end, Q
         java<<formatDoc(body, indent+" * ");
     if (!end.isEmpty())
     {
-        QStringList lines = QStringList::split( "\n", end);
+        QStringList lines = end.split( "\n" );
         for (int i= 0; i < lines.count(); i++)
             java<<formatDoc(lines[i], indent+" * ");
     }
@@ -505,7 +505,7 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
     if (roleName.isEmpty())
         return;
 
-    QString scope = scopeToJavaDecl(visib);
+    QString scope = visib.toString();
 
     // always put space between this and prior decl, if any
     writeBlankLine(java);
@@ -518,12 +518,12 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
     // multiplicity object that we don't have to figure out what it means via regex.
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).toLower());
         java<<startline<<scope<<" "<<fieldClassName<<" "<<fieldVarName<<";";
     }
     else
     {
-        QString fieldVarName = roleName.lower() + "Vector";
+        QString fieldVarName = roleName.toLower() + "Vector";
         java<<startline<<scope<<" Vector "<<fieldVarName<<" = new Vector();";
         // from here we could initialize default values, or put in an init() section
         // of the constructors
@@ -576,13 +576,13 @@ void JavaWriter::writeAssociationRoleMethod (QString fieldClassName, QString rol
 {
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).toLower());
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, visib, change, false, java);
     }
     else
     {
-        QString fieldVarName = roleName.lower() + "Vector";
+        QString fieldVarName = roleName.toLower() + "Vector";
         writeVectorAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, visib, change, java);
     }
@@ -596,7 +596,7 @@ void JavaWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QS
 
     fieldClassName = fixTypeName(fieldClassName);
     fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
-    QString strVis = scopeToJavaDecl(visibility);
+    QString strVis = visibility.toString();
 
     // ONLY IF changeability is NOT Frozen
     if (changeType != Uml::chg_Frozen)
@@ -632,7 +632,7 @@ void JavaWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QSt
         bool isFinal, QTextStream &java)
 {
 
-    QString strVis = scopeToJavaDecl(visibility);
+    QString strVis = visibility.toString();
     fieldClassName = fixTypeName(fieldClassName);
     fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
 
@@ -711,7 +711,8 @@ bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
     if (atl1.count() != atl2.count())
         return false;
     for (UMLAttributeListIt atl1It( atl1 ), atl2It( atl2 ); atl1It.hasNext() && atl2It.hasNext(); ) {
-        UMLAttribute *at1, *at2;
+        UMLAttribute *at1 = atl1It.next();
+        UMLAttribute *at2 = atl2It.next();
         if (at1->getTypeName() != at2->getTypeName())
             return false;
     }
@@ -837,7 +838,7 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
 
         str = ""; // reset for next method
         str += ((op->getAbstract() && !isInterface) ? "abstract ":"");
-        str += scopeToJavaDecl(op->getVisibility()) + ' ';
+        str += op->getVisibility().toString() + ' ';
         str += (op->getStatic() ? "static ":"");
         str += methodReturnType + ' ' +cleanName(op->getName()) + "( ";
 
@@ -869,8 +870,9 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
     }
 }
 
-QString JavaWriter::fixInitialStringDeclValue(QString value, QString type)
+QString JavaWriter::fixInitialStringDeclValue(const QString& val, QString type)
 {
+    QString value = val;
     // check for strings only
     if (!value.isEmpty() && type == "String") {
         if (!value.startsWith('"'))
@@ -881,25 +883,6 @@ QString JavaWriter::fixInitialStringDeclValue(QString value, QString type)
     return value;
 }
 
-QString JavaWriter::scopeToJavaDecl(Uml::Visibility scope)
-{
-    QString scopeString;
-    switch(scope)
-    {
-      case Uml::Visibility::Public:
-        scopeString = "public";
-        break;
-      case Uml::Visibility::Protected:
-        scopeString = "protected";
-        break;
-      case Uml::Visibility::Private:
-    default:
-        scopeString = "private";
-        break;
-    }
-    return scopeString;
-}
-
 // methods like this _shouldn't_ be needed IF we properly did things thruought the code.
 QString JavaWriter::getUMLObjectName(UMLObject *obj)
 {
