@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -55,7 +55,7 @@ bool PascalWriter::isOOClass(UMLClassifier *c) {
     if (ot == Uml::ot_Enum)
         return false;
     if (ot != Uml::ot_Class) {
-        kDebug() << "PascalWriter::isOOClass: unknown object type " << ot;
+        uDebug() << "unknown object type " << ot;
         return false;
     }
     QString stype = c->getStereotype();
@@ -122,13 +122,13 @@ void PascalWriter::computeAssocTypeAndRole
 
 void PascalWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kDebug() << "Cannot write class of NULL concept!";
+        uDebug() << "Cannot write class of NULL concept!";
         return;
     }
 
     const bool isClass = !c->isInterface();
     QString classname = cleanName(c->getName());
-    QString fileName = qualifiedName(c).lower();
+    QString fileName = qualifiedName(c).toLower();
     fileName.replace('.', '-');
 
     //find an appropriate name for our file
@@ -152,7 +152,7 @@ void PascalWriter::writeClass(UMLClassifier *c) {
     str = getHeadingFile(".pas");
     if (!str.isEmpty()) {
         str.replace(QRegExp("%filename%"), fileName);
-        str.replace(QRegExp("%filepath%"), file.name());
+        str.replace(QRegExp("%filepath%"), file.fileName());
         pas << str << endl;
     }
 
@@ -249,7 +249,7 @@ void PascalWriter::writeClass(UMLClassifier *c) {
     }
     pas << m_endl;
 
-    ClassifierInfo info(c, UMLApp::app()->getDocument());
+    ClassifierInfo info(c);
     UMLAttributeList atpub = info.atpub;
     if (isClass && (forceSections() || atpub.count())) {
         pas << getIndent() << "// Public attributes:" << m_endl;
@@ -405,7 +405,7 @@ bool PascalWriter::isReservedKeyword(const QString & rPossiblyReservedKeyword) {
 
     QStringList::ConstIterator it;
     for (it = keywords.begin(); it != keywords.end(); ++it)
-        if ((*it).lower() == rPossiblyReservedKeyword.lower())
+        if ((*it).toLower() == rPossiblyReservedKeyword.toLower())
             return true;
 
     return false;
