@@ -1,7 +1,7 @@
 /***************************************************************************
     begin                : Wed Jan 22 2003
     copyright            : (C) 2003 by David Hugh-Jones
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
+      (C) 2004-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
     email                : hughjonesd@yahoo.co.uk
  ***************************************************************************/
 
@@ -87,7 +87,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
 void PerlWriter::writeClass(UMLClassifier *c) {
 
   /*  if(!c) {
-      kDebug()<<"Cannot write class of NULL concept!";
+      uDebug()<<"Cannot write class of NULL concept!";
       return;
       }
   */
@@ -116,7 +116,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   // actual solution: shameful ".pm" hack in codegenerator
 
   CodeGenerationPolicy *pol = UMLApp::app()->getCommonPolicy();
-  QString curDir = pol->getOutputDirectory().absPath();
+  QString curDir = pol->getOutputDirectory().absolutePath();
   if (fileName.contains("::")) {
     // create new directories for each level
     QString newDir;
@@ -144,7 +144,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     emit codeGenerated(c, false);
     return;
   }
-  QString oldDir = pol->getOutputDirectory().absPath();
+  QString oldDir = pol->getOutputDirectory().absolutePath();
   pol->setOutputDirectory(curDir);
   QFile fileperl;
   if(!openFile(fileperl, fileName)) {
@@ -171,7 +171,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     str.replace(QRegExp("%date%"),QDate::currentDate().toString());
     str.replace(QRegExp("%time%"),QTime::currentTime().toString());
     str.replace(QRegExp("%package-name%"),ThisPkgName);
-    if(str.find(QRegExp("%PACKAGE-DECLARE%"))){
+    if(str.indexOf(QRegExp("%PACKAGE-DECLARE%"))){
       str.replace(QRegExp("%PACKAGE-DECLARE%"),
                   "package " + ThisPkgName + ';'
                   + m_endl + m_endl
@@ -183,7 +183,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
       bPackageDeclared = true;
     }
 
-    if(str.find(QRegExp("%USE-STATEMENTS%"))){
+    if(str.indexOf(QRegExp("%USE-STATEMENTS%"))){
       QString UseStms;
       if(GetUseStatements(c,UseStms,ThisPkgName)){
         str.replace(QRegExp("%USE-STATEMENTS%"), UseStms);
@@ -222,7 +222,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     //Write class Documentation
   if(forceDoc() || !c->getDoc().isEmpty()) {
     perl << m_endl << "=head1";
-    perl << " " << classname.upper() << m_endl << m_endl;
+    perl << " " << classname.toUpper() << m_endl << m_endl;
     perl << c->getDoc();
     perl << m_endl << m_endl << "=cut" << m_endl << m_endl;
   }
