@@ -2,7 +2,7 @@
     begin               : Thu Jul 26 2005
     copyright           : (C) 2005 by Rene Meyer
     email               : rene.meyer@sturmit.de
-      (C) 2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
+      (C) 2006-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
  ***************************************************************************/
 
 /***************************************************************************
@@ -96,7 +96,7 @@ TclWriter::writeClass(UMLClassifier * c)
 {
 
     if (!c) {
-        kDebug() << "Cannot write class of NULL concept!\n";
+        uDebug() << "Cannot write class of NULL concept!\n";
         return;
     }
     QFile           fileh, filetcl;
@@ -113,7 +113,7 @@ TclWriter::writeClass(UMLClassifier * c)
         return;
     }
     // preparations
-    classifierInfo = new ClassifierInfo(c, m_doc);
+    classifierInfo = new ClassifierInfo(c);
     classifierInfo->fileName = fileName;
     classifierInfo->className = cleanName(c->getName());
     mClass = cleanName(c->getName());
@@ -644,8 +644,8 @@ TclWriter::writeInitAttributeSource()
         m_indentLevel++;
 
         // first, initiation of fields derived from attributes
-        UMLAttributeList *atl = classifierInfo->getAttList();
-        foreach (UMLAttribute * at , *atl ) {
+        UMLAttributeList atl = classifierInfo->getAttList();
+        foreach (UMLAttribute * at , atl ) {
             if (!at->getInitialValue().isEmpty()) {
                 varName = cleanName(at->getName());
                 writeCode("set " + varName + ' ' + at->getInitialValue());
