@@ -86,7 +86,7 @@ QString formatComment(const QString &comment) {
     if (comment.isEmpty())
         return comment;
 
-    QStringList lines = QStringList::split("\n", comment);
+    QStringList lines = comment.split("\n");
     QString& first = lines.first();
     QRegExp wordex("\\w");
     if (first.startsWith("/*")) {
@@ -97,7 +97,7 @@ QString formatComment(const QString &comment) {
             lines.pop_front();  // nothing interesting on this line
     }
     QString& last = lines.last();
-    int endpos = last.find("*/");
+    int endpos = last.indexOf("*/");
     if (endpos != -1) {
         if (last.contains(wordex))
             last = last.mid(0, endpos - 1);  // remove comment end
@@ -134,7 +134,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
     const Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
     if (parentPkg == NULL) {
-        // kDebug() << "Import_Utils::createUMLObject(" << name
+        // uDebug() << "Import_Utils::createUMLObject(" << name
         //     << "): parentPkg is NULL, assuming Logical View" << endl;
         parentPkg = logicalView;
     }
@@ -158,9 +158,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             // Find, or create, the scopes.
             QStringList components;
             if (typeName.contains("::")) {
-                components = QStringList::split("::", typeName);
+                components = typeName.split("::");
             } else if (typeName.contains(".")) {
-                components = QStringList::split(".", typeName);
+                components = typeName.split(".");
             }
             if (components.count() > 1) {
                 typeName = components.back();
@@ -212,7 +212,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (c)
                 dt->setOriginType(c);
             else
-                kError() << "createUMLObject(" << name << "): "
+                uError() << "createUMLObject(" << name << "): "
                 << "origType " << typeName << " is not a UMLClassifier"
                 << endl;
             if (isRef || isPointer)
@@ -234,7 +234,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (existingPkg)
                 existingPkg->removeObject(o);
             else
-                kError() << "createUMLObject(" << name << "): "
+                uError() << "createUMLObject(" << name << "): "
                     << "o->getUMLPackage() was NULL" << endl;
             o->setUMLPackage(parentPkg);
             parentPkg->addObject(o);
@@ -255,7 +255,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
         return o;
     // Create dependencies on template parameters.
     QString caption = templateInstantiation.cap(1);
-    QStringList params = QStringList::split(QRegExp("[^\\w:\\.]+"), caption);
+    QStringList params = caption.split(QRegExp("[^\\w:\\.]+"));
     if (!params.count())
         return o;
     QStringList::Iterator end(params.end());
@@ -288,7 +288,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
     Uml::Object_Type ot = owner->getBaseType();
     Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
     if (! (ot == Uml::ot_Class || ot == Uml::ot_Interface && pl == Uml::pl_Java)) {
-        kDebug() << "insertAttribute: Don't know what to do with "
+        uDebug() << "insertAttribute: Don't know what to do with "
         << owner->getName() << " (object type " << ot << ")" << endl;
         return NULL;
     }
@@ -440,9 +440,9 @@ void createGeneralization(UMLClassifier *child, const QString &parentName) {
 
 QStringList includePathList() {
     QStringList includePathList(incPathList);
-    char *umbrello_incpath = getenv( "UMBRELLO_INCPATH" );
-    if (umbrello_incpath) {
-        includePathList += QStringList::split( ':', umbrello_incpath );
+    QString umbrello_incpath = QString(getenv("UMBRELLO_INCPATH"));
+    if (!umbrello_incpath.isEmpty()) {
+        includePathList += umbrello_incpath.split( ':' );
     }
     return includePathList;
 }
