@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2006                                                *
+ *  copyright (C) 2003-2007                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -71,7 +71,7 @@ void ClassifierListPage::setupPage() {
         typeName = i18n( "Constraints" );
         newItemType = i18n( "N&ew Constraint..." );
     } else {
-        kWarning() << "unknown listItem type in ClassifierListPage";
+        uWarning() << "unknown listItem type in ClassifierListPage";
     }
 
     int margin = fontMetrics().height();
@@ -323,7 +323,7 @@ void ClassifierListPage::slotRightButtonPressed(Q3ListBoxItem* item, const QPoin
         } else if (m_itemType == ot_EntityAttribute) {
             type = ListPopupMenu::mt_EntityAttribute_Selected;
         } else {
-            kWarning() << "unknown type in ClassifierListPage";
+            uWarning() << "unknown type in ClassifierListPage";
         }
     } else { //pressed into fresh air
         if (m_itemType == ot_Attribute) {
@@ -337,30 +337,30 @@ void ClassifierListPage::slotRightButtonPressed(Q3ListBoxItem* item, const QPoin
         } else if (m_itemType == ot_EntityAttribute) {
             type = ListPopupMenu::mt_New_EntityAttribute;
         } else {
-            kWarning() << "unknown type in ClassifierListPage";
+            uWarning() << "unknown type in ClassifierListPage";
         }
     }
     if(m_pMenu) {
         m_pMenu->hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotPopupMenuSel(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotPopupMenuSel(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
     m_pMenu = new ListPopupMenu(this, type);
 
     m_pMenu->popup(p);
-    connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotPopupMenuSel(int)));
+    connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotPopupMenuSel(QAction*)));
 }
 
-void ClassifierListPage::slotPopupMenuSel(int id) {
+void ClassifierListPage::slotPopupMenuSel(QAction* action) {
     int currentItemIndex = m_pItemListLB->currentItem();
-
     if ( currentItemIndex == -1 )
         return;
 
+    ListPopupMenu::Menu_Type id = m_pMenu->getMenuType(action);
     UMLClassifierListItem* listItem = getItemList().at( currentItemIndex );
     if(!listItem && id != ListPopupMenu::mt_New_Attribute) {
-        kDebug() << "can't find att from selection";
+        uDebug() << "can't find att from selection";
         return;
     }
     switch(id) {
@@ -384,6 +384,9 @@ void ClassifierListPage::slotPopupMenuSel(int id) {
     case ListPopupMenu::mt_Properties:
         slotProperties();
         break;
+
+    default:
+        uDebug() << "Menu_Type " << id << " not implemented" << endl;
     }
 }
 
@@ -394,7 +397,7 @@ void ClassifierListPage::printItemList(const QString &prologue) {
     UMLClassifierListItemList itemList = getItemList();
     for (UMLClassifierListItemListIt it(itemList); (item = it.current()) != NULL; ++it)
         buf.append(' ' + item->getName());
-    kDebug() << prologue << buf;
+    uDebug() << prologue << buf;
 #endif
 }
 
@@ -422,8 +425,7 @@ void ClassifierListPage::slotTopClicked() {
     //     Reason: getItemList() returns only a subset of all entries
     //     in UMLClassifier::m_List.
     takeItem(currentAtt, true, index);  // now we index the UMLClassifier::m_List
-    kDebug() << "ClassifierListPage::slotTopClicked(" << currentAtt->getName()
-            << "): peer index in UMLCanvasItem::m_List is " << index << endl;
+    uDebug() << currentAtt->getName() << ": peer index in UMLCanvasItem::m_List is " << index << endl;
     addClassifier(currentAtt, 0);
     printItemList("itemList after change: ");
     slotClicked(item);
@@ -454,8 +456,7 @@ void ClassifierListPage::slotUpClicked() {
     //     Reason: getItemList() returns only a subset of all entries
     //     in UMLClassifier::m_List.
     takeItem(currentAtt, true, index);  // now we index the UMLClassifier::m_List
-    kDebug() << "ClassifierListPage::slotUpClicked(" << currentAtt->getName()
-        << "): peer index in UMLCanvasItem::m_List is " << index << endl;
+    uDebug() << currentAtt->getName() << ": peer index in UMLCanvasItem::m_List is " << index << endl;
     if (index == -1)
         index = 0;
     addClassifier(currentAtt, index);
@@ -487,8 +488,7 @@ void ClassifierListPage::slotDownClicked() {
     //     Reason: getItemList() returns only a subset of all entries
     //     in UMLClassifier::m_List.
     takeItem(currentAtt, false, index);  // now we index the UMLClassifier::m_List
-    kDebug() << "ClassifierListPage::slotDownClicked(" << currentAtt->getName()
-        << "): peer index in UMLCanvasItem::m_List is " << index << endl;
+    uDebug() << currentAtt->getName() << ": peer index in UMLCanvasItem::m_List is " << index << endl;
     if (index != -1)
         index++;   // because we want to go _after_ the following peer item
     addClassifier(currentAtt, index);
@@ -520,8 +520,7 @@ void ClassifierListPage::slotBottomClicked() {
     //     Reason: getItemList() returns only a subset of all entries
     //     in UMLClassifier::m_List.
     takeItem(currentAtt, false, index);  // now we index the UMLClassifier::m_List
-    kDebug() << "ClassifierListPage::slotDownClicked(" << currentAtt->getName()
-            << "): peer index in UMLCanvasItem::m_List is " << index << endl;
+    uDebug() << currentAtt->getName() << ": peer index in UMLCanvasItem::m_List is " << index << endl;
     addClassifier(currentAtt, getItemList().count());
     printItemList("itemList after change: ");
     slotClicked( item );
@@ -533,7 +532,7 @@ void ClassifierListPage::slotDoubleClick( Q3ListBoxItem* item ) {
 
     UMLClassifierListItem* listItem  = getItemList().at( m_pItemListLB->index( item ) );
     if( !listItem ) {
-        kDebug() << "can't find att from selection";
+        uDebug() << "can't find att from selection";
         return;
     }
 
@@ -618,11 +617,11 @@ bool ClassifierListPage::addClassifier(UMLClassifierListItem* listitem, int posi
             break;
         }
     default: {
-            kWarning() << "unknown type in ClassifierListPage";
+            uWarning() << "unknown type in ClassifierListPage";
             return false;
         }
     }
-    kError() << "ClassifierListPage::addClassifier unable to handle listitem type in current state" << endl;
+    uError() << "unable to handle listitem type in current state" << endl;
     return false;
 }
 
@@ -633,11 +632,10 @@ bool ClassifierListPage::takeItem(UMLClassifierListItem* listItem,
         return false;
     qApp->processEvents();
     peerIndex = -1;
-    UMLObject *o;
     const Uml::Object_Type seekType = listItem->getBaseType();
     UMLObjectList listItems = m_pClassifier->subordinates();
-    UMLObjectListIt it(listItems);
-    for (int i = 0; it.hasNext(); ++i, it.next()) {
+    for (int i = 0; i < listItems.count(); ++i) {
+        UMLObject *o = listItems.at(i);
         if (seekPeerBefore) {
             if (i >= wasAtIndex)
                 break;
