@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -277,41 +277,45 @@ void UMLOperationDialog::slotNameChanged( const QString &_text )
 
 void UMLOperationDialog::slotParmRightButtonPressed(Q3ListBoxItem *item, const QPoint &p) {
     ListPopupMenu::Menu_Type type = ListPopupMenu::mt_Undefined;
-    if(item)//pressed on an item
+    if (item)//pressed on an item
     {
         type = ListPopupMenu::mt_Parameter_Selected;
     } else//pressed into fresh air
     {
         type = ListPopupMenu::mt_New_Parameter;
     }
-    if(m_pMenu) {
+    if (m_pMenu) {
         m_pMenu -> hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
     m_pMenu = new ListPopupMenu(this, type);
     m_pMenu->popup(p);
-    connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
+    connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
 
 }
 
 void UMLOperationDialog::slotParmRightButtonClicked(Q3ListBoxItem */*item*/, const QPoint &/*p*/) {
-    if(m_pMenu) {
+    if (m_pMenu) {
         m_pMenu -> hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotParmPopupMenuSel(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotParmPopupMenuSel(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
 }
 
 void UMLOperationDialog::slotParmDoubleClick(Q3ListBoxItem *item) {
-    if(!item)
+    if (!item)
         return;
-    slotParmPopupMenuSel(ListPopupMenu::mt_Properties);
+    if (m_pMenu) {
+        QAction* action = m_pMenu->getAction(ListPopupMenu::mt_Properties);
+        slotParmPopupMenuSel(action);
+    }
 }
 
-void UMLOperationDialog::slotParmPopupMenuSel(int id) {
+void UMLOperationDialog::slotParmPopupMenuSel(QAction* action) {
+    ListPopupMenu::Menu_Type id = m_pMenu->getMenuType(action);
     if( id == ListPopupMenu::mt_Rename || id == ListPopupMenu::mt_Properties ) {
         slotParameterProperties();
     } else if( id == ListPopupMenu::mt_New_Parameter ) {
@@ -379,7 +383,7 @@ void UMLOperationDialog::slotParameterProperties() {
     pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     if( !pOldAtt ) {
-        kDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText();
+        uDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText();
         return;
     }//should never occur
     ParmPropDlg dlg(this, m_doc, pOldAtt);
@@ -409,8 +413,7 @@ void UMLOperationDialog::slotParameterProperties() {
                 }
                 if (!breakFlag) {
                     // Nothing found: set type name directly. Bad.
-                    kDebug() << "UMLOperationDialog::slotParameterProperties: "
-                    << typeName << " not found." << endl;
+                    uDebug() << typeName << " not found." << endl;
                     pOldAtt->setTypeName( typeName );  // Bad.
                 }
             }
@@ -427,7 +430,7 @@ void UMLOperationDialog::slotParameterProperties() {
 
 void UMLOperationDialog::slotParameterUp()
 {
-    kDebug() ;
+    uDebug() ;
     UMLAttribute* pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     m_pOperation->moveParmLeft( pOldAtt );
