@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2004-2006                                                *
+ *  copyright (C) 2004-2007                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -119,9 +119,9 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     }
 #endif
     if (name.contains("::"))
-        components = QStringList::split("::", name);
+        components = name.split("::");
     else if (name.contains('.'))
-        components = QStringList::split('.', name);
+        components = name.split('.');
     QString nameWithoutFirstPrefix;
     if (components.size() > 1) {
         name = components.front();
@@ -143,12 +143,12 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
                 if (caseSensitive) {
                     if (pkg->getName() == name)
                         return pkg;
-                } else if (pkg->getName().lower() == name.lower()) {
+                } else if (pkg->getName().toLower() == name.toLower()) {
                     return pkg;
                 }
             }
             if (seenPkgs.indexOf(pkg) != -1) {
-                kError() << "findUMLObject(" << name << "): "
+                uError() << "findUMLObject(" << name << "): "
                     << "breaking out of cycle involving "
                     << pkg->getName() << endl;
                 break;
@@ -160,13 +160,13 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
                 if (caseSensitive) {
                     if (obj->getName() != name)
                         continue;
-                } else if (obj->getName().lower() != name.lower()) {
+                } else if (obj->getName().toLower() != name.toLower()) {
                     continue;
                 }
                 Uml::Object_Type foundType = obj->getBaseType();
                 if (nameWithoutFirstPrefix.isEmpty()) {
                     if (type != Uml::ot_UMLObject && type != foundType) {
-                        kDebug() << "findUMLObject: type mismatch for "
+                        uDebug() << "findUMLObject: type mismatch for "
                             << name << " (seeking type: "
                             << type << ", found type: "
                             << foundType << ")" << endl;
@@ -190,7 +190,7 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
                     foundType != Uml::ot_Class &&
                     foundType != Uml::ot_Interface &&
                     foundType != Uml::ot_Component) {
-                    kDebug() << "findUMLObject: found \"" << name
+                    uDebug() << "findUMLObject: found \"" << name
                         << "\" is not a package (?)" << endl;
                     continue;
                 }
@@ -206,13 +206,13 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
         if (caseSensitive) {
             if (obj->getName() != name)
                 continue;
-        } else if (obj->getName().lower() != name.lower()) {
+        } else if (obj->getName().toLower() != name.toLower()) {
             continue;
         }
         Uml::Object_Type foundType = obj->getBaseType();
         if (nameWithoutFirstPrefix.isEmpty()) {
             if (type != Uml::ot_UMLObject && type != foundType) {
-                kDebug() << "findUMLObject: type mismatch for "
+                uDebug() << "findUMLObject: type mismatch for "
                     << name << " (seeking type: "
                     << type << ", found type: "
                     << foundType << ")" << endl;
@@ -225,7 +225,7 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
             foundType != Uml::ot_Class &&
             foundType != Uml::ot_Interface &&
             foundType != Uml::ot_Component) {
-            kDebug() << "findUMLObject: found \"" << name
+            uDebug() << "findUMLObject: found \"" << name
                 << "\" is not a package (?)" << endl;
             continue;
         }
@@ -269,7 +269,7 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
             currentName = i18n("new_category");
         else {
             currentName = i18n("new_object");
-            kWarning() << "unknown object type in umldoc::uniqObjectName()";
+            uWarning() << "unknown object type in umldoc::uniqObjectName()";
         }
     }
     UMLDoc *doc = UMLApp::app()->getDocument();
@@ -310,7 +310,7 @@ bool isCommonDataType(QString type) {
         if (caseSensitive) {
             if (type == *it)
                 return true;
-        } else if (type.lower() == (*it).lower()) {
+        } else if (type.toLower() == (*it).toLower()) {
             return true;
         }
     }
@@ -425,7 +425,7 @@ Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningSc
     if (t.isEmpty())
         return PS_Empty;
 
-    QStringList nameAndType = QStringList::split( QRegExp("\\s*:\\s*"), t);
+    QStringList nameAndType = t.split( QRegExp("\\s*:\\s*"));
     if (nameAndType.count() == 2) {
         UMLObject *pType = NULL;
         if (nameAndType[1] != "class") {
@@ -448,7 +448,7 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
     if (a.isEmpty())
         return PS_Empty;
 
-    int colonPos = a.find(':');
+    int colonPos = a.indexOf(':');
     if (colonPos < 0) {
         nmTp = NameAndType(a, NULL);
         return PS_OK;
@@ -489,7 +489,7 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
         nmTp = NameAndType(name, NULL, pd);
         return PS_OK;
     }
-    QStringList typeAndInitialValue = QStringList::split( QRegExp("\\s*=\\s*"), a );
+    QStringList typeAndInitialValue = a.split( QRegExp("\\s*=\\s*") );
     const QString &type = typeAndInitialValue[0];
     UMLObject *pType = pDoc->findUMLObject(type, Uml::ot_UMLObject, owningScope);
     if (pType == NULL) {
@@ -553,7 +553,7 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     arglist = arglist.trimmed();
     if (arglist.isEmpty())
         return PS_OK;
-    QStringList args = QStringList::split( QRegExp("\\s*,\\s*"), arglist);
+    QStringList args = arglist.split( QRegExp("\\s*,\\s*") );
     for (QStringList::Iterator lit = args.begin(); lit != args.end(); ++lit) {
         NameAndType nmTp;
         Parse_Status ps = parseAttribute(*lit, nmTp, owningScope);
@@ -571,7 +571,7 @@ Parse_Status parseConstraint(QString m, QString& name, UMLEntity* /*owningScope*
     if (m.isEmpty())
         return PS_Empty;
 
-    int colonPos = m.find(':');
+    int colonPos = m.indexOf(':');
     if (colonPos < 0) {
         name = m;
         return PS_OK;
@@ -799,7 +799,7 @@ Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt) {
             mt = Uml::mt_EntityRelationship;
             break;
         default:
-            kError() << "Model_Utils::convert_DT_MT: illegal input value " << dt << endl;
+            uError() << "Model_Utils::convert_DT_MT: illegal input value " << dt << endl;
             mt = Uml::N_MODELTYPES;
             break;
     }
@@ -894,7 +894,7 @@ Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt) {
         break;
 
     default:
-        kWarning() << "convert_DT_LVT() called on unknown diagram type";
+        uWarning() << "convert_DT_LVT() called on unknown diagram type";
     }
     return type;
 }
@@ -948,7 +948,7 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
                     return type;
                 }
             } while ((f = static_cast<UMLFolder*>(f->getUMLPackage())) != NULL);
-            kError() << "convert_OT_LVT(" << o->getName()
+            uError() << "convert_OT_LVT(" << o->getName()
                 << "): internal error - object is not properly nested in folder"
                 << endl;
         }
