@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -63,7 +63,6 @@
 #include "umlviewlist.h"
 #include "worktoolbar.h"
 #include "model_utils.h"
-#include "clipboard/umlclipboard.h"
 #include "dialogs/classwizard.h"
 #include "dialogs/codegenerationwizard.h"
 #include "dialogs/codeviewerdialog.h"
@@ -97,7 +96,7 @@ QMenu* UMLApp::findMenu(KMenuBar* /*menu*/, const QString &name)
     QWidget* widget = factory()->container(name, this);
     if (widget)
         return dynamic_cast<QMenu*>(widget);
-    kDebug() << "UMLApp::findMenu(KMenuBar*): factory()->container(" << name << ") returns NULL";
+    uDebug() << "factory()->container(" << name << ") returns NULL";
     return 0;
 }
 
@@ -1414,7 +1413,6 @@ void UMLApp::readOptionState() {
 
 /** Call the code viewing assistant on a code document */
 void UMLApp::viewCodeDocument(UMLClassifier* classifier) {
-
     CodeGenerator * currentGen = getGenerator();
     if(currentGen && classifier) {
         if(!dynamic_cast<SimpleCodeGenerator*>(currentGen))
@@ -1435,6 +1433,8 @@ void UMLApp::viewCodeDocument(UMLClassifier* classifier) {
         } else {
             KMessageBox::sorry(0, i18n("Cannot view code from simple code writer."),i18n("Cannot View Code"));
         }
+    } else {
+        uWarning() << "No CodeGenerator or UMLClassifier given!" << endl;
     }
 
 }
@@ -1654,13 +1654,13 @@ void UMLApp::setDiagramMenuItemsState(bool bState) {
 void UMLApp::slotUpdateViews() {
     QMenu* menu = findMenu( menuBar(), QString("views") );
     if (!menu) {
-        kWarning() << "view menu not found";
+        uWarning() << "view menu not found";
         return;
     }
 
     menu = findMenu( menu, QString("show_view") );
     if (!menu) {
-        kWarning() << "show menu not found";
+        uWarning() << "show menu not found";
         return;
     }
 
@@ -1758,7 +1758,7 @@ void UMLApp::slotDeleteSelectedWidget() {
     if ( getCurrentView() ) {
         getCurrentView()->deleteSelection();
     } else {
-        kWarning() << " trying to delete widgets when there is no current view (see bug 59774)";
+        uWarning() << " trying to delete widgets when there is no current view (see bug 59774)";
     }
 }
 
@@ -1884,7 +1884,7 @@ QWidget* UMLApp::getMainViewWidget() {
 void UMLApp::setCurrentView(UMLView* view) {
     m_view = view;
     if (view == NULL) {
-        kDebug() << "UMLApp::setCurrentView: view is NULL";
+        uDebug() << "view is NULL";
         return;
     }
 
@@ -1918,7 +1918,7 @@ QMenu* UMLApp::findMenu(QMenu* /*menu*/, const QString &name) {
     QWidget* widget = factory()->container(name, this);
     if (widget)
         return dynamic_cast<QMenu*>(widget);
-    kDebug() << "UMLApp::findMenu: factory()->container(" << name << ") returns NULL";
+    uDebug() << "factory()->container(" << name << ") returns NULL";
     return 0;
 }
 
@@ -1937,7 +1937,7 @@ void UMLApp::slotChangeTabLeft() {
     UMLView *currView = m_view;
     int viewIndex = 0;
     if ( (viewIndex = views.indexOf(currView)) < 0) {
-        kError() << "UMLApp::slotChangeTabLeft(): currView not found in viewlist" << endl;
+        uError() << "currView not found in viewlist" << endl;
         return;
     }
     UMLView* prevView = NULL;
@@ -1960,7 +1960,7 @@ void UMLApp::slotChangeTabRight() {
     UMLView *currView = m_view;
     int viewIndex = 0;
     if (( viewIndex = views.indexOf(currView) ) < 0) {
-        kError() << "UMLApp::slotChangeTabRight(): currView not found in viewlist" << endl;
+        uError() << "currView not found in viewlist" << endl;
         return;
     }
     UMLView* nextView = NULL;
@@ -2009,7 +2009,7 @@ void UMLApp::clearUndoStack() {
 
 void UMLApp::undo()
 {
-    kDebug() << "UMLApp::undo(" << m_pUndoStack->undoText() << ") [" << m_pUndoStack->count() << "]";
+    uDebug() << m_pUndoStack->undoText() << " [" << m_pUndoStack->count() << "]";
     m_pUndoStack->undo();
 
     if(m_pUndoStack->canUndo())
@@ -2022,7 +2022,7 @@ void UMLApp::undo()
 
 void UMLApp::redo()
 {
-    kDebug() << "UMLApp::undo(" << m_pUndoStack->redoText() << ") [" << m_pUndoStack->count() << "]";
+    uDebug() << m_pUndoStack->redoText() << " [" << m_pUndoStack->count() << "]";
     m_pUndoStack->redo();
 
     if(m_pUndoStack->canRedo())
@@ -2038,7 +2038,7 @@ void UMLApp::executeCommand(QUndoCommand* cmd)
     if(cmd != NULL)
         m_pUndoStack->push(cmd);
 
-    kDebug() << "UMLApp::executeCommand(" << cmd->text() << ") [" << m_pUndoStack->count() << "]";
+    uDebug() << cmd->text() << " [" << m_pUndoStack->count() << "]";
 
     UMLApp::app()->enableUndo(true);
 }
