@@ -226,7 +226,7 @@ void UMLWidget::init() {
         m_Font       = optionState.uiState.font;
         m_bShowStereotype = optionState.classState.showStereoType;
     } else {
-        kError() << "UMLWidget::init: SERIOUS PROBLEM - m_pView is NULL" << endl;
+        uError() << "SERIOUS PROBLEM - m_pView is NULL" << endl;
         m_bUseFillColour = false;
         m_bUsesDiagramFillColour = false;
         m_bUsesDiagramUseFillColour = false;
@@ -258,12 +258,12 @@ void UMLWidget::init() {
     setZ(m_origZ = 2);  // default for most widgets
 }
 
-void UMLWidget::slotMenuSelection(int sel) {
-    QFont font;
+void UMLWidget::slotMenuSelection(QAction* action) {
     QColor newColour;
     const Uml::Widget_Type wt = m_Type;
     UMLWidget* widget = 0; // use for select the first object properties (fill, line color)
 
+    ListPopupMenu::Menu_Type sel = m_pMenu->getMenuType(action);
     switch(sel) {
     case ListPopupMenu::mt_Rename:
         m_pDoc -> renameUMLObject(m_pObject);
@@ -290,13 +290,12 @@ void UMLWidget::slotMenuSelection(int sel) {
              m_pObject->showProperties();
              UMLApp::app()->EndMacro();
         } else {
-            kWarning() << "making properties dialog for unknown widget type";
+            uWarning() << "making properties dialog for unknown widget type";
         }
         // adjustAssocs( getX(), getY() );//adjust assoc lines
         break;
 
     case ListPopupMenu::mt_Line_Color:
-    case ListPopupMenu::mt_Line_Color_Selection:
         widget = m_pView->getFirstMultiSelectedWidget();
         if (widget) { newColour = widget->getLineColor(); }
         if( KColorDialog::getColor(newColour) ) {
@@ -307,7 +306,6 @@ void UMLWidget::slotMenuSelection(int sel) {
         break;
 
     case ListPopupMenu::mt_Fill_Color:
-    case ListPopupMenu::mt_Fill_Color_Selection:
         widget = m_pView->getFirstMultiSelectedWidget();
         if (widget) { newColour = widget->getFillColour(); }
         if ( KColorDialog::getColor(newColour) ) {
@@ -348,18 +346,12 @@ void UMLWidget::slotMenuSelection(int sel) {
         break;
 
     case ListPopupMenu::mt_Change_Font:
-        font = getFont();
-        if( KFontDialog::getFont( font, false, m_pView ) )
-        {
-            UMLApp::app()->executeCommand(new cmdChangeFontSelection(m_pDoc,m_pView,font));
-        }
-        break;
-
     case ListPopupMenu::mt_Change_Font_Selection:
-        font = getFont();
-        if( KFontDialog::getFont( font, false, m_pView ) )
         {
-            UMLApp::app()->executeCommand(new cmdChangeFontSelection(m_pDoc,m_pView,font));
+            QFont font = getFont();
+            if (KFontDialog::getFont(font, false, m_pView)) {
+                UMLApp::app()->executeCommand(new cmdChangeFontSelection(m_pDoc, m_pView, font));
+            }
         }
         break;
 
@@ -402,6 +394,9 @@ void UMLWidget::slotMenuSelection(int sel) {
             ft->handleRename();
             break;
         }
+
+    default:
+        uDebug() << "Menu_Type " << sel << " not implemented" << endl;
     }
 }
 
@@ -503,8 +498,7 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */) {
     if (widgetHasUMLObject(m_Type) && m_pObject == NULL) {
         m_pObject = m_pDoc->findObjectById(m_nId);
         if (m_pObject == NULL) {
-            kError() << "UMLWidget::activate: cannot find UMLObject with id="
-                << ID2STR(m_nId) << endl;
+            uError() << "cannot find UMLObject with id=" << ID2STR(m_nId) << endl;
             return false;
         }
     }
@@ -580,7 +574,7 @@ void UMLWidget::addAssoc(AssociationWidget* pAssoc) {
 
 void UMLWidget::removeAssoc(AssociationWidget* pAssoc) {
     if(pAssoc) {
-        m_Assocs.remove(pAssoc);
+        m_Assocs.removeAll(pAssoc);
     }
 }
 
@@ -636,7 +630,7 @@ void UMLWidget::showProperties() {
         docwindow->showDocumentation( getUMLObject() , true );
         m_pDoc->setModified(true);
     }
-    dlg->close(true); //wipe from memory
+    dlg->close(); //wipe from memory
 }
 
 void UMLWidget::startPopupMenu( const QPoint &At) {
@@ -665,16 +659,16 @@ void UMLWidget::startPopupMenu( const QPoint &At) {
     // disable the "view code" menu for simple code generators
     CodeGenerator * currentCG = UMLApp::app()->getGenerator();
     if(currentCG && dynamic_cast<SimpleCodeGenerator*>(currentCG))
-        m_pMenu->setItemEnabled(ListPopupMenu::mt_ViewCode, false);
+        m_pMenu->setActionEnabled(ListPopupMenu::mt_ViewCode, false);
 
     m_pMenu->popup(At);
 
-    connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotMenuSelection(int)));
+    connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotMenuSelection(QAction*)));
 }
 
 void UMLWidget::slotRemovePopupMenu() {
     if(m_pMenu) {
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotMenuSelection(int)));
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotMenuSelection(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
@@ -734,8 +728,7 @@ void UMLWidget::setSelected(bool _select) {
     const QPoint pos(getX(), getY());
     UMLWidget *bkgnd = m_pView->getWidgetAt(pos);
     if (bkgnd && bkgnd != this && _select) {
-        kDebug() << "UMLWidget::setSelected: setting Z to "
-            << bkgnd->getZ() + 1 << ", SelectState: " << _select << endl;
+        uDebug() << "setting Z to " << bkgnd->getZ() + 1 << ", SelectState: " << _select << endl;
         setZ( bkgnd->getZ() + 1 );
     } else {
         setZ( m_origZ );
@@ -1029,7 +1022,7 @@ bool UMLWidget::loadFromXMI( QDomElement & qElement ) {
         m_Font.fromString(font);
         //setFont(newFont);
     } else {
-        kWarning() << "Using default font " << m_Font.toString()
+        uWarning() << "Using default font " << m_Font.toString()
         << " for widget with xmi.id " << ID2STR(m_nId) << endl;
         //setFont( m_Font );
     }
